@@ -73,8 +73,8 @@ casereader_read (struct casereader *reader)
         {
           size_t n_widths UNUSED = caseproto_get_n_widths (reader->proto);
           assert (case_get_n_values (c) >= n_widths);
-          expensive_assert (caseproto_equal (case_get_proto (c), 0,
-                                             reader->proto, 0, n_widths));
+          expensive_assert (caseproto_range_equal (case_get_proto (c), 0,
+                                                   reader->proto, 0, n_widths));
           return c;
         }
     }
@@ -147,8 +147,9 @@ casereader_swap (struct casereader *a, struct casereader *b)
    when it is no longer needed.  Returns a null pointer if cases
    have been exhausted or upon detection of an I/O error. */
 struct ccase *
-casereader_peek (struct casereader *reader, casenumber idx)
+casereader_peek (const struct casereader *reader_, casenumber idx)
 {
+  struct casereader *reader = CONST_CAST (struct casereader *, reader_);
   if (idx < reader->n_cases)
     {
       struct ccase *c;
@@ -171,7 +172,7 @@ casereader_peek (struct casereader *reader, casenumber idx)
    casereader_read will return true, because an error can occur
    in the meantime.) */
 bool
-casereader_is_empty (struct casereader *reader)
+casereader_is_empty (const struct casereader *reader)
 {
   if (reader->n_cases == 0)
     return true;
@@ -500,7 +501,8 @@ advance_random_reader (struct casereader *reader,
   if (new > old)
     {
       shared->min_offset = new;
-      shared->class->advance (reader, shared->aux, new - old);
+      if (shared->class->advance)
+        shared->class->advance (reader, shared->aux, new - old);
     }
 }
 
