@@ -57,10 +57,10 @@ struct file_handle
     enum fh_referent referent;  /* What the file handle refers to. */
 
     /* FH_REF_FILE only. */
-    char *file_name;		/* File name as provided by user. */
-    char *file_name_encoding;	/* The character encoding of file_name,
-				   This is NOT the encoding of the file contents! */
-    enum fh_mode mode;  	/* File mode. */
+    char *file_name;                /* File name as provided by user. */
+    char *file_name_encoding;        /* The character encoding of file_name,
+                                   This is NOT the encoding of the file contents! */
+    enum fh_mode mode;          /* File mode. */
     enum fh_line_ends line_ends; /* Line ends for text files. */
 
     /* FH_REF_FILE and FH_REF_INLINE only. */
@@ -191,6 +191,8 @@ void
 fh_unname (struct file_handle *handle)
 {
   assert (handle->ref_cnt > 1);
+  if (fh_get_default_handle () == handle)
+    fh_set_default_handle (NULL);
   if (handle != fh_inline_file () && handle->id != NULL)
     unname_handle (handle);
 }
@@ -205,9 +207,7 @@ fh_from_id (const char *id)
   HMAP_FOR_EACH_WITH_HASH (handle, struct file_handle, name_node,
                            utf8_hash_case_string (id, 0), &named_handles)
     if (!utf8_strcasecmp (id, handle->id))
-      {
-	return fh_ref (handle);
-      }
+      return fh_ref (handle);
 
   return NULL;
 }
@@ -222,19 +222,18 @@ static struct file_handle *
 create_handle (const char *id, char *handle_name, enum fh_referent referent,
                const char *encoding)
 {
-  struct file_handle *handle = XZALLOC (struct file_handle);
+  struct file_handle *handle = xmalloc (sizeof *handle);
+  *handle = (struct file_handle) {
+    .ref_cnt = 1,
+    .id = xstrdup_if_nonnull (id),
+    .name = handle_name,
+    .referent = referent,
+    .encoding = xstrdup (encoding),
+  };
 
-  handle->ref_cnt = 1;
-  handle->id = xstrdup_if_nonnull (id);
-  handle->name = handle_name;
-  handle->referent = referent;
-  handle->encoding = xstrdup (encoding);
-
-  if (id != NULL)
-    {
-      hmap_insert (&named_handles, &handle->name_node,
-                   utf8_hash_case_string (handle->id, 0));
-    }
+  if (id)
+    hmap_insert (&named_handles, &handle->name_node,
+                 utf8_hash_case_string (handle->id, 0));
 
   return handle;
 }
@@ -256,11 +255,9 @@ struct file_handle *
 fh_create_file (const char *id, const char *file_name, const char *file_name_encoding,
                 const struct fh_properties *properties)
 {
-  char *handle_name;
-  struct file_handle *handle;
-
-  handle_name = id != NULL ? xstrdup (id) : xasprintf ("`%s'", file_name);
-  handle = create_handle (id, handle_name, FH_REF_FILE, properties->encoding);
+  char *handle_name = id ? xstrdup (id) : xasprintf ("`%s'", file_name);
+  struct file_handle *handle = create_handle (id, handle_name, FH_REF_FILE,
+                                              properties->encoding);
   handle->file_name = xstrdup (file_name);
   handle->file_name_encoding = xstrdup_if_nonnull (file_name_encoding);
   handle->mode = properties->mode;
@@ -539,10 +536,10 @@ fh_lock (struct file_handle *h, enum fh_referent mask UNUSED,
   HMAP_FOR_EACH_WITH_HASH (lock, struct fh_lock, node, hash, &locks)
     {
       if (0 == compare_fh_locks (lock, key))
-	{
-	  found_lock = true;
-	  break;
-	}
+        {
+          found_lock = true;
+          break;
+        }
     }
 
   if (found_lock)
@@ -578,10 +575,10 @@ fh_lock (struct file_handle *h, enum fh_referent mask UNUSED,
   HMAP_FOR_EACH_WITH_HASH (lock, struct fh_lock, node, hash, &locks)
     {
       if (0 == compare_fh_locks (lock, key))
-	{
-	  found_lock = true;
-	  break;
-	}
+        {
+          found_lock = true;
+          break;
+        }
     }
 
   assert (found_lock);
@@ -608,7 +605,7 @@ fh_unlock (struct fh_lock *lock)
       assert (lock->open_cnt > 0);
       if (--lock->open_cnt == 0)
         {
-	  hmap_delete (&locks, &lock->node);
+          hmap_delete (&locks, &lock->node);
           free_key (lock);
           free (lock);
           return false;
@@ -653,10 +650,10 @@ fh_is_locked (const struct file_handle *handle, enum fh_access access)
   HMAP_FOR_EACH_WITH_HASH (k, struct fh_lock, node, hash, &locks)
     {
       if (0 == compare_fh_locks (k, &key))
-	{
-	  is_locked = true;
-	  break;
-	}
+        {
+          is_locked = true;
+          break;
+        }
     }
 
   free_key (&key);
@@ -788,11 +785,11 @@ fh_get_identity (const struct file_handle *fh)
     ok = GetFileInformationByHandle (h, &fi);
     if (ok)
       {
-	identity->device = fi.dwVolumeSerialNumber;
-	identity->inode = fi.nFileIndexHigh;
-	identity->inode <<= (sizeof fi.nFileIndexLow) * CHAR_BIT;
-	identity->inode |= fi.nFileIndexLow;
-	identity->name = 0;
+        identity->device = fi.dwVolumeSerialNumber;
+        identity->inode = fi.nFileIndexHigh;
+        identity->inode <<= (sizeof fi.nFileIndexLow) * CHAR_BIT;
+        identity->inode |= fi.nFileIndexLow;
+        identity->name = 0;
       }
     CloseHandle (h);
   }
@@ -807,9 +804,9 @@ fh_get_identity (const struct file_handle *fh)
       char *cname = NULL;
       do
       {
-	bufsize = pathlen;
-	cname = xrealloc (cname, bufsize);
-	pathlen = GetFullPathName (file_name, bufsize, cname, NULL);
+        bufsize = pathlen;
+        cname = xrealloc (cname, bufsize);
+        pathlen = GetFullPathName (file_name, bufsize, cname, NULL);
       }
       while (pathlen > bufsize);
       identity->name = xstrdup (cname);
