@@ -43,6 +43,7 @@
 #include "gl/xmalloca.h"
 
 #include "gettext.h"
+#include "xvasprintf.h"
 #define _(msgid) gettext (msgid)
 
 
@@ -99,7 +100,7 @@ fn_search_path (const char *base_name, char **path)
 
       struct stat temp;
       if (((stat (file, &temp) == 0) && (! S_ISDIR (temp.st_mode))))
-	return file;
+        return file;
 
       free (file);
     }
@@ -164,7 +165,7 @@ fn_open (const struct file_handle *fh, const char *mode)
   if (fn[0] == '|')
     {
       if (settings_get_safer_mode ())
-	return safety_violation (fn);
+        return safety_violation (fn);
 
       return popen (&fn[1], mode[0] == 'r' ? "r" : "w");
     }
@@ -174,7 +175,7 @@ fn_open (const struct file_handle *fh, const char *mode)
       FILE *f;
 
       if (settings_get_safer_mode ())
-	return safety_violation (fn);
+        return safety_violation (fn);
 
       s = xmalloca (strlen (fn));
       memcpy (s, fn, strlen (fn) - 1);
@@ -238,22 +239,22 @@ default_output_path (void)
   if (path == NULL)
     {
       /* Windows NT defines HOMEDRIVE and HOMEPATH.  But give preference
-	 to HOME, because the user can change HOME.  */
+         to HOME, because the user can change HOME.  */
       const char *home_dir = getenv ("HOME");
       int i;
 
       if (home_dir == NULL)
-	{
-	  const char *home_drive = getenv ("HOMEDRIVE");
-	  const char *home_path = getenv ("HOMEPATH");
+        {
+          const char *home_drive = getenv ("HOMEDRIVE");
+          const char *home_path = getenv ("HOMEPATH");
 
-	  if (home_drive != NULL && home_path != NULL)
-	    home_dir = xasprintf ("%s%s",
-				  home_drive, home_path);
-	}
+          if (home_drive != NULL && home_path != NULL)
+            home_dir = xasprintf ("%s%s",
+                                  home_drive, home_path);
+        }
 
       if (home_dir == NULL)
-	home_dir = "c:/users/default"; /* poor default */
+        home_dir = "c:/users/default"; /* poor default */
 
       /* Copy home_dir into path.  Add a slash at the end but
          only if there isn't already one there, because Windows
@@ -265,12 +266,18 @@ default_output_path (void)
         path = xstrdup (home_dir);
 
       for(i = 0; i < strlen (path); i++)
-	if (path[i] == '\\') path[i] = '/';
+        if (path[i] == '\\') path[i] = '/';
     }
 
   return path;
 }
 
+const char *
+default_log_path (void)
+{
+  return default_output_path ();
+}
+
 #else
 
 /* ... whereas the rest of the world just likes it to be
@@ -283,5 +290,32 @@ default_output_path (void)
   return current_dir;
 }
 
+const char *
+default_log_path (void)
+{
+  static char *log_path = NULL;
+
+  if (!log_path)
+    {
+      char *tmp = NULL;
+      const char *state_home = getenv ("XDG_STATE_HOME");
+      if (!state_home)
+        {
+          const char *home = getenv ("HOME");
+          state_home = tmp = xasprintf ("%s/.local/state", home ? home : "");
+        }
+
+      log_path = xasprintf ("%s/pspp/", state_home);
+
+      struct stat s;
+      if (!stat (state_home, &s) && stat (log_path, &s) && errno == ENOENT)
+        mkdir (log_path, 0700);
+
+      free (tmp);
+    }
+
+  return log_path;
+}
+
 #endif
 
