@@ -20,6 +20,7 @@
 #include <ctype.h>
 #include <stdbool.h>
 #include <unitypes.h>
+#include "data/dict-class.h"
 #include "libpspp/str.h"
 #include "gl/verify.h"
 
@@ -37,7 +38,7 @@
     TOKEN_TYPE(ASTERISK)            /* * */                             \
     TOKEN_TYPE(SLASH)               /* / */                             \
     TOKEN_TYPE(EQUALS)              /* = */                             \
-    TOKEN_TYPE(LPAREN)              /* (*/                              \
+    TOKEN_TYPE(LPAREN)              /* ( */                             \
     TOKEN_TYPE(RPAREN)              /* ) */                             \
     TOKEN_TYPE(LBRACK)              /* [ */                             \
     TOKEN_TYPE(RBRACK)              /* ] */                             \
@@ -89,8 +90,12 @@ bool lex_is_keyword (enum token_type);
 /* Validating identifiers. */
 #define ID_MAX_LEN 64          /* Maximum length of identifier, in bytes. */
 
-bool id_is_valid (const char *id, const char *dict_encoding, bool issue_error);
-bool id_is_plausible (const char *id, bool issue_error);
+bool id_is_valid (const char *id, const char *dict_encoding, enum dict_class);
+bool id_is_plausible (const char *id);
+char *id_is_valid__ (const char *id, const char *dict_encoding,
+                     enum dict_class)
+  WARN_UNUSED_RESULT;
+char *id_is_plausible__ (const char *id) WARN_UNUSED_RESULT;
 
 /* Recognizing identifiers. */
 bool lex_is_id1 (char);
