@@ -70,8 +70,8 @@ struct pcp_main_header
   {
     char product[63];           /* "PCSPSS SYSTEM FILE..." */
     unsigned int nominal_case_size; /* Number of var positions. */
-    char creation_date[9];	/* "[m]m/dd/yy". */
-    char creation_time[9];	/* "[H]H:MM:SS". */
+    char creation_date[9];        /* "[m]m/dd/yy". */
+    char creation_time[9];        /* "[H]H:MM:SS". */
     char file_label[65];        /* File label. */
     unsigned int weight_index;  /* Index of weighting variable, 0 if none. */
   };
@@ -80,6 +80,9 @@ struct pcp_var_record
   {
     unsigned int pos;
 
+    bool drop;
+    union value tmp;
+
     char name[9];
     int width;
     struct fmt_spec format;
@@ -90,8 +93,6 @@ struct pcp_var_record
 
     struct pcp_value_label *val_labs;
     size_t n_val_labs;
-
-    struct variable *var;
   };
 
 struct pcp_value_label
@@ -395,14 +396,6 @@ pcp_get_strings (const struct any_reader *r_, struct pool *pool,
   return aux.n;
 }
 
-static void
-find_and_delete_var (struct dictionary *dict, const char *name)
-{
-  struct variable *var = dict_lookup_var (dict, name);
-  if (var)
-    dict_delete_var (dict, var);
-}
-
 /* Decodes the dictionary read from R, saving it into *DICT.  Character
    strings in R are decoded using ENCODING, or an encoding obtained from R if
    ENCODING is null, or the locale encoding if R specifies no encoding.
@@ -444,10 +437,6 @@ pcp_decode (struct any_reader *r_, const char *encoding,
      dictionary and may destroy or modify its variables. */
   r->proto = caseproto_ref_pool (dict_get_proto (dict), r->pool);
 
-  find_and_delete_var (dict, "CASENUM_");
-  find_and_delete_var (dict, "DATE_");
-  find_and_delete_var (dict, "WEIGHT_");
-
   *dictp = dict;
   if (infop)
     {
@@ -755,7 +744,7 @@ read_variables_record (struct pcp_reader *r)
       var->format.w = (format >> 8) & 0xff;
       var->format.d = format & 0xff;
       fmt_fix_output (&var->format);
-      var->width = fmt_var_width (&var->format);
+      var->width = fmt_var_width (var->format);
 
       if (var_label_ofs)
         {
@@ -839,7 +828,6 @@ parse_variable_records (struct pcp_reader *r, struct dictionary *dict,
 
   for (rec = var_recs; rec < &var_recs[n_var_recs]; rec++)
     {
-      struct variable *var;
       char *name;
       size_t i;
 
@@ -847,25 +835,27 @@ parse_variable_records (struct pcp_reader *r, struct dictionary *dict,
                                  rec->name, -1, r->pool);
       name[strcspn (name, " ")] = '\0';
 
-      /* Transform $DATE => DATE_, $WEIGHT => WEIGHT_, $CASENUM => CASENUM_. */
-      if (name[0] == '$')
-        name = pool_asprintf (r->pool, "%s_", name + 1);
+      /* Drop system variables. */
+      rec->drop = name[0] == '$';
+      if (rec->drop)
+        {
+          value_init_pool (r->pool, &rec->tmp, rec->width);
+          continue;
+        }
 
-      if (!dict_id_is_valid (dict, name, false) || name[0] == '#')
+      if (!dict_id_is_valid (dict, name, DC_ORDINARY))
         {
           pcp_error (r, rec->pos, _("Invalid variable name `%s'."), name);
           return false;
         }
 
-      var = rec->var = dict_create_var (dict, name, rec->width);
+      struct variable *var = dict_create_var (dict, name, rec->width);
       if (var == NULL)
         {
-          char *new_name = dict_make_unique_var_name (dict, NULL, NULL);
+          var = dict_create_var_with_unique_name (dict, name, rec->width);
           pcp_warn (r, rec->pos, _("Renaming variable with duplicate name "
                                    "`%s' to `%s'."),
-                    name, new_name);
-          var = rec->var = dict_create_var_assert (dict, new_name, rec->width);
-          free (new_name);
+                    name, var_get_name (var));
         }
       if (rec->weight)
         {
@@ -924,7 +914,7 @@ parse_variable_records (struct pcp_reader *r, struct dictionary *dict,
         }
 
       /* Set formats. */
-      var_set_both_formats (var, &rec->format);
+      var_set_both_formats (var, rec->format);
     }
 
   return true;
@@ -957,10 +947,11 @@ pcp_file_casereader_read (struct casereader *reader, void *r_)
   r->n_cases--;
 
   c = case_create (r->proto);
+  size_t case_idx = 0;
   for (i = 0; i < r->n_vars; i++)
     {
       struct pcp_var_record *var = &r->vars[i];
-      union value *v = case_data_rw_idx (c, i);
+      union value *v = var->drop ? &var->tmp : case_data_rw_idx (c, case_idx++);
 
       if (var->width == 0)
         retval = read_case_number (r, &v->f);
