@@ -58,10 +58,10 @@ struct pfm_writer
   {
     struct file_handle *fh;     /* File handle. */
     struct fh_lock *lock;       /* Lock on file handle. */
-    FILE *file;			/* File stream. */
+    FILE *file;                        /* File stream. */
     struct replace_file *rf;    /* Ticket for replacing output file. */
 
-    int lc;			/* Number of characters on this line so far. */
+    int lc;                        /* Number of characters on this line so far. */
 
     size_t n_vars;              /* Number of variables. */
     struct pfm_var *vars;       /* Variables. */
@@ -130,7 +130,7 @@ pfm_open_writer (struct file_handle *fh, struct dictionary *dict,
       const struct variable *dv = dict_get_var (dict, i);
       struct pfm_var *pv = &w->vars[i];
       pv->width = MIN (var_get_width (dv), MAX_POR_WIDTH);
-      pv->case_index = var_get_case_index (dv);
+      pv->case_index = var_get_dict_index (dv);
     }
 
   w->digits = opts.digits;
@@ -350,8 +350,8 @@ write_variables (struct pfm_writer *w, struct dictionary *dict)
       buf_write (w, "7", 1);
       write_int (w, width);
       write_string (w, var_get_short_name (v, 0));
-      write_format (w, *var_get_print_format (v), width);
-      write_format (w, *var_get_write_format (v), width);
+      write_format (w, var_get_print_format (v), width);
+      write_format (w, var_get_write_format (v), width);
 
       /* Write missing values. */
       mv_copy (&mv, var_get_missing_values (v));
@@ -409,7 +409,7 @@ write_value_labels (struct pfm_writer *w, const struct dictionary *dict)
       int j;
 
       if (n_labels == 0)
-	continue;
+        continue;
 
       buf_write (w, "D", 1);
       write_int (w, 1);
