@@ -1,5 +1,5 @@
 /* PSPP - a program for statistical analysis.
-   Copyright (C) 1997-9, 2000, 2006, 2007, 2009, 2010, 2011, 2015 Free Software Foundation, Inc.
+   Copyright (C) 1997-9, 2000, 2006, 2007, 2009, 2010, 2011, 2015, 2023 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -74,6 +74,7 @@ struct settings
   struct fmt_spec default_format;
   bool testing_mode;
   int fuzzbits;
+  int scalemin;
 
   int cmd_algorithm;
   int global_algorithm;
@@ -86,6 +87,8 @@ struct settings
 
   enum settings_value_show show_values;
   enum settings_value_show show_variables;
+
+  char *table_summary;
 };
 
 static struct settings the_settings = {
@@ -122,11 +125,13 @@ static struct settings the_settings = {
   .default_format = { .type = FMT_F, .w = 8, .d = 2 },
   .testing_mode = false,
   .fuzzbits = 6,
+  .scalemin = 24,
   .cmd_algorithm = ENHANCED,
   .global_algorithm = ENHANCED,
   .syntax = ENHANCED,
   .styles = FMT_SETTINGS_INIT,
   .small = .0001,
+  .table_summary = 0,
 
   /* output_routing */
   .output_routing = {
@@ -188,6 +193,7 @@ settings_destroy (struct settings *s)
   if (s != NULL)
     {
       fmt_settings_uninit (&s->styles);
+      free (s->table_summary);
       if (s != &the_settings)
         free (s);
     }
@@ -234,7 +240,7 @@ settings_get_output_integer_format (void)
 /* Sets the output integer format to INTEGER_FORMAT. */
 void
 settings_set_output_integer_format (
-			   enum integer_format integer_format)
+                           enum integer_format integer_format)
 {
   the_settings.output_integer_format = integer_format;
 }
@@ -390,17 +396,17 @@ settings_set_max_messages (enum msg_severity severity, int max)
   if (severity == MSG_S_WARNING)
     {
       if (max == 0)
-	{
-	  msg (MW,
-	       _("MXWARNS set to zero.  No further warnings will be given even when potentially problematic situations are encountered."));
-	  msg_ui_disable_warnings (true);
-	}
+        {
+          msg (MW,
+               _("MXWARNS set to zero.  No further warnings will be given even when potentially problematic situations are encountered."));
+          msg_ui_disable_warnings (true);
+        }
       else if (the_settings.max_messages [MSG_S_WARNING] == 0)
-	{
-	  msg_ui_disable_warnings (false);
-	  the_settings.max_messages[MSG_S_WARNING] = max;
-	  msg (MW, _("Warnings re-enabled. %d warnings will be issued before aborting syntax processing."), max);
-	}
+        {
+          msg_ui_disable_warnings (false);
+          the_settings.max_messages[MSG_S_WARNING] = max;
+          msg (MW, _("Warnings re-enabled. %d warnings will be issued before aborting syntax processing."), max);
+        }
     }
 
   the_settings.max_messages[severity] = max;
@@ -507,18 +513,18 @@ settings_set_workspace (size_t workspace)
 
 /* Default format for variables created by transformations and by
    DATA LIST {FREE,LIST}. */
-const struct fmt_spec *
+struct fmt_spec
 settings_get_format (void)
 {
-  return &the_settings.default_format;
+  return the_settings.default_format;
 }
 
 /* Set default format for variables created by transformations
    and by DATA LIST {FREE,LIST}. */
 void
-settings_set_format (const struct fmt_spec *default_format)
+settings_set_format (const struct fmt_spec default_format)
 {
-  the_settings.default_format = *default_format;
+  the_settings.default_format = default_format;
 }
 
 /* Are we in testing mode?  (e.g. --testing-mode command line
@@ -548,6 +554,18 @@ settings_set_fuzzbits (int fuzzbits)
   the_settings.fuzzbits = fuzzbits;
 }
 
+int
+settings_get_scalemin (void)
+{
+  return the_settings.scalemin;
+}
+
+void
+settings_set_scalemin (int scalemin)
+{
+  the_settings.scalemin = scalemin;
+}
+
 /* Return the current algorithm setting */
 enum behavior_mode
 settings_get_algorithm (void)
@@ -591,22 +609,21 @@ settings_set_syntax (enum behavior_mode mode)
 }
 
 
-/* Sets custom currency specifier CC having name CC_NAME ('A' through
-   'E') to correspond to the settings in CC_STRING. */
-bool
+/* Sets custom currency specifier CC having name CC_NAME ('A' through 'E') to
+   correspond to the settings in CC_STRING.  Returns NULL if successful,
+   otherwise an error message that the caller must free. */
+char * WARN_UNUSED_RESULT
 settings_set_cc (const char *cc_string, enum fmt_type type)
 {
   struct fmt_number_style *style = fmt_number_style_from_string (cc_string);
   if (!style)
-    {
-      msg (SE, _("%s: Custom currency string `%s' does not contain "
-                 "exactly three periods or commas (or it contains both)."),
-           fmt_name (type), cc_string);
-      return false;
-    }
+    return xasprintf (_("Custom currency string `%s' for %s does not contain "
+                        "exactly three periods or commas (or it contains "
+                        "both)."),
+                      fmt_name (type), cc_string);
 
   fmt_settings_set_cc (&the_settings.styles, type, style);
-  return true;
+  return NULL;
 }
 
 void
@@ -627,6 +644,26 @@ settings_get_fmt_settings (void)
   return &the_settings.styles;
 }
 
+char *
+settings_get_summary (void)
+{
+  return the_settings.table_summary;
+}
+
+void
+settings_set_summary (const char *s)
+{
+  free (the_settings.table_summary);
+
+  if (s == NULL)
+    {
+      the_settings.table_summary = NULL;
+      return;
+    }
+
+  the_settings.table_summary = xstrdup (s);
+}
+
 double
 settings_get_small (void)
 {
@@ -643,18 +680,18 @@ settings_set_small (double small)
    which must be of type FMT_DOLLAR.  The caller must free the
    string. */
 char *
-settings_dollar_template (const struct fmt_spec *fmt)
+settings_dollar_template (const struct fmt_spec fmt)
 {
   struct string str = DS_EMPTY_INITIALIZER;
   int c;
   const struct fmt_number_style *fns ;
 
-  assert (fmt->type == FMT_DOLLAR);
+  assert (fmt.type == FMT_DOLLAR);
 
-  fns = fmt_settings_get_style (&the_settings.styles, fmt->type);
+  fns = fmt_settings_get_style (&the_settings.styles, fmt.type);
 
   ds_put_byte (&str, '$');
-  for (c = MAX (fmt->w - fmt->d - 1, 0); c > 0;)
+  for (c = MAX (fmt.w - fmt.d - 1, 0); c > 0;)
     {
       ds_put_byte (&str, '#');
       if (--c % 4 == 0 && c > 0)
@@ -663,10 +700,10 @@ settings_dollar_template (const struct fmt_spec *fmt)
           --c;
         }
     }
-  if (fmt->d > 0)
+  if (fmt.d > 0)
     {
       ds_put_byte (&str, fns->decimal);
-      ds_put_byte_multiple (&str, '#', fmt->d);
+      ds_put_byte_multiple (&str, '#', fmt.d);
     }
 
   return ds_cstr (&str);
