@@ -63,6 +63,7 @@ const GEnumValue align[] =
 
 const GEnumValue measure[] =
   {
+    {MEASURE_UNKNOWN, "unknown", N_("Unknown")},
     {MEASURE_NOMINAL, "nominal", N_("Nominal")},
     {MEASURE_ORDINAL, "ordinal", N_("Ordinal")},
     {MEASURE_SCALE,   "scale", N_("Scale")},
@@ -86,12 +87,12 @@ struct variable
     int ref_cnt;
     /* Dictionary information. */
     char *name;                 /* Variable name.  Mixed case. */
-    int width;			/* 0 for numeric, otherwise string width. */
+    int width;                        /* 0 for numeric, otherwise string width. */
     struct missing_values miss; /* Missing values. */
-    struct fmt_spec print;	/* Default format for PRINT. */
-    struct fmt_spec write;	/* Default format for WRITE. */
+    struct fmt_spec print;        /* Default format for PRINT. */
+    struct fmt_spec write;        /* Default format for WRITE. */
     struct val_labs *val_labs;  /* Value labels. */
-    char *label;		/* Variable label. */
+    char *label;                /* Variable label. */
     struct string name_and_label; /* The name and label in the same string */
 
     /* GUI information. */
@@ -116,8 +117,8 @@ struct variable
   };
 
 
-static void var_set_print_format_quiet (struct variable *v, const struct fmt_spec *print);
-static void var_set_write_format_quiet (struct variable *v, const struct fmt_spec *write);
+static void var_set_print_format_quiet (struct variable *v, struct fmt_spec);
+static void var_set_write_format_quiet (struct variable *v, struct fmt_spec);
 static void var_set_label_quiet (struct variable *v, const char *label);
 static void var_set_name_quiet (struct variable *v, const char *name);
 
@@ -139,7 +140,7 @@ var_create (const char *name, int width)
   v->leave = var_must_leave (v);
   type = val_type_from_width (width);
   v->alignment = var_default_alignment (type);
-  v->measure = var_default_measure (type);
+  v->measure = var_default_measure_for_type (type);
   v->role = ROLE_INPUT;
   v->display_width = var_default_display_width (width);
   v->print = v->write = var_default_formats (width);
@@ -299,7 +300,7 @@ var_get_width (const struct variable *v)
 
 void
 var_set_width_and_formats (struct variable *v, int new_width,
-			   const struct fmt_spec *print, const struct fmt_spec *write)
+                           const struct fmt_spec *print, const struct fmt_spec *write)
 {
   struct variable *ov;
   unsigned int traits = 0;
@@ -342,13 +343,13 @@ var_set_width_and_formats (struct variable *v, int new_width,
 
   if (print)
     {
-      var_set_print_format_quiet (v, print);
+      var_set_print_format_quiet (v, *print);
       traits |= VAR_TRAIT_PRINT_FORMAT;
     }
 
   if (write)
     {
-      var_set_write_format_quiet (v, write);
+      var_set_write_format_quiet (v, *write);
       traits |= VAR_TRAIT_WRITE_FORMAT;
     }
 
@@ -565,9 +566,9 @@ var_lookup_value_label (const struct variable *v, const union value *value)
 */
 static void
 append_value (const struct variable *v, const union value *value,
-	      struct string *str)
+              struct string *str)
 {
-  char *s = data_out (value, var_get_encoding (v), &v->print,
+  char *s = data_out (value, var_get_encoding (v), v->print,
                       settings_get_fmt_settings ());
   struct substring ss = ss_cstr (s);
   ss_rtrim (&ss, ss_cstr (" "));
@@ -590,9 +591,9 @@ var_append_value_name__ (const struct variable *v, const union value *value,
     default:
     case SETTINGS_VALUE_SHOW_LABEL:
       if (label)
-	ds_put_cstr (str, label);
+        ds_put_cstr (str, label);
       else
-	append_value (v, value, str);
+        append_value (v, value, str);
       break;
 
     case SETTINGS_VALUE_SHOW_BOTH:
@@ -610,7 +611,7 @@ var_append_value_name__ (const struct variable *v, const union value *value,
 */
 void
 var_append_value_name (const struct variable *v, const union value *value,
-		       struct string *str)
+                       struct string *str)
 {
   var_append_value_name__ (v, value, settings_get_show_values (), str);
 }
@@ -618,10 +619,10 @@ var_append_value_name (const struct variable *v, const union value *value,
 /* Print and write formats. */
 
 /* Returns V's print format specification. */
-const struct fmt_spec *
+struct fmt_spec
 var_get_print_format (const struct variable *v)
 {
-  return &v->print;
+  return v->print;
 }
 
 /* Sets V's print format specification to PRINT, which must be a
@@ -629,12 +630,12 @@ var_get_print_format (const struct variable *v)
    (ordinarily an output format, but input formats are not
    rejected). */
 static void
-var_set_print_format_quiet (struct variable *v, const struct fmt_spec *print)
+var_set_print_format_quiet (struct variable *v, struct fmt_spec print)
 {
-  if (!fmt_equal (&v->print, print))
+  if (!fmt_equal (v->print, print))
     {
       assert (fmt_check_width_compat (print, v->width));
-      v->print = *print;
+      v->print = print;
     }
 }
 
@@ -643,7 +644,7 @@ var_set_print_format_quiet (struct variable *v, const struct fmt_spec *print)
    (ordinarily an output format, but input formats are not
    rejected). */
 void
-var_set_print_format (struct variable *v, const struct fmt_spec *print)
+var_set_print_format (struct variable *v, struct fmt_spec print)
 {
   struct variable *ov = var_clone (v);
   var_set_print_format_quiet (v, print);
@@ -651,10 +652,10 @@ var_set_print_format (struct variable *v, const struct fmt_spec *print)
 }
 
 /* Returns V's write format specification. */
-const struct fmt_spec *
+struct fmt_spec
 var_get_write_format (const struct variable *v)
 {
-  return &v->write;
+  return v->write;
 }
 
 /* Sets V's write format specification to WRITE, which must be a
@@ -662,12 +663,12 @@ var_get_write_format (const struct variable *v)
    (ordinarily an output format, but input formats are not
    rejected). */
 static void
-var_set_write_format_quiet (struct variable *v, const struct fmt_spec *write)
+var_set_write_format_quiet (struct variable *v, struct fmt_spec write)
 {
-  if (!fmt_equal (&v->write, write))
+  if (!fmt_equal (v->write, write))
     {
       assert (fmt_check_width_compat (write, v->width));
-      v->write = *write;
+      v->write = write;
     }
 }
 
@@ -676,7 +677,7 @@ var_set_write_format_quiet (struct variable *v, const struct fmt_spec *write)
    (ordinarily an output format, but input formats are not
    rejected). */
 void
-var_set_write_format (struct variable *v, const struct fmt_spec *write)
+var_set_write_format (struct variable *v, struct fmt_spec write)
 {
   struct variable *ov = var_clone (v);
   var_set_write_format_quiet (v, write);
@@ -689,7 +690,7 @@ var_set_write_format (struct variable *v, const struct fmt_spec *write)
    V's width (ordinarily an output format, but input formats are
    not rejected). */
 void
-var_set_both_formats (struct variable *v, const struct fmt_spec *format)
+var_set_both_formats (struct variable *v, struct fmt_spec format)
 {
   struct variable *ov = var_clone (v);
   var_set_print_format_quiet (v, format);
@@ -759,23 +760,20 @@ var_get_label (const struct variable *v)
 
 /* Sets V's variable label to UTF-8 encoded string LABEL, stripping off leading
    and trailing white space.  If LABEL is a null pointer or if LABEL is an
-   empty string (after stripping white space), then V's variable label (if any)
-   is removed. */
+   empty string, then V's variable label (if any) is removed. */
 static void
 var_set_label_quiet (struct variable *v, const char *label)
 {
   free (v->label);
   v->label = NULL;
 
-  if (label != NULL && label[strspn (label, CC_SPACES)])
+  if (label != NULL && label[0])
     v->label = xstrdup (label);
 
   ds_destroy (&v->name_and_label);
   ds_init_empty (&v->name_and_label);
 }
 
-
-
 /* Sets V's variable label to UTF-8 encoded string LABEL, stripping off leading
    and trailing white space.  If LABEL is a null pointer or if LABEL is an
    empty string (after stripping white space), then V's variable label (if any)
@@ -788,7 +786,6 @@ var_set_label (struct variable *v, const char *label)
   dict_var_changed (v, VAR_TRAIT_LABEL, ov);
 }
 
-
 /* Removes any variable label from V. */
 void
 var_clear_label (struct variable *v)
@@ -809,7 +806,8 @@ var_has_label (const struct variable *v)
 bool
 measure_is_valid (enum measure m)
 {
-  return m == MEASURE_NOMINAL || m == MEASURE_ORDINAL || m == MEASURE_SCALE;
+  return (m == MEASURE_UNKNOWN || m == MEASURE_NOMINAL
+          || m == MEASURE_ORDINAL || m == MEASURE_SCALE);
 }
 
 /* Returns a string version of measurement level M, for display to a user.
@@ -873,9 +871,38 @@ var_set_measure (struct variable *v, enum measure measure)
    used to reset a variable's measurement level to the
    default. */
 enum measure
-var_default_measure (enum val_type type)
+var_default_measure_for_type (enum val_type type)
 {
-  return type == VAL_NUMERIC ? MEASURE_SCALE : MEASURE_NOMINAL;
+  return type == VAL_NUMERIC ? MEASURE_UNKNOWN : MEASURE_NOMINAL;
+}
+
+/* Returns the default measurement level for a variable with the given
+   FORMAT, or MEASURE_UNKNOWN if there is no good default. */
+enum measure
+var_default_measure_for_format (enum fmt_type format)
+{
+  if (format == FMT_DOLLAR)
+    return MEASURE_SCALE;
+
+  switch (fmt_get_category (format))
+    {
+    case FMT_CAT_BASIC:
+    case FMT_CAT_LEGACY:
+    case FMT_CAT_BINARY:
+    case FMT_CAT_HEXADECIMAL:
+      return MEASURE_UNKNOWN;
+
+    case FMT_CAT_CUSTOM:
+    case FMT_CAT_DATE:
+    case FMT_CAT_TIME:
+      return MEASURE_SCALE;
+
+    case FMT_CAT_DATE_COMPONENT:
+    case FMT_CAT_STRING:
+      return MEASURE_NOMINAL;
+    }
+
+  NOT_REACHED ();
 }
 
 /* Returns true if M is a valid variable role,
@@ -1194,17 +1221,6 @@ var_get_dict_index (const struct variable *v)
   assert (var_has_vardict (v));
   return vardict_get_dict_index (v->vardict);
 }
-
-/* Returns V's index within the case represented by its
-   dictionary, that is, the value for which "case_data_idx (case,
-   index)" will return the data for V in that case.
-   V must be in a dictionary. */
-size_t
-var_get_case_index (const struct variable *v)
-{
-  assert (var_has_vardict (v));
-  return vardict_get_case_index (v->vardict);
-}
 
 /* Returns variable V's attribute set.  The caller may examine or
    modify the attribute set, but must not destroy it.  Destroying
@@ -1326,15 +1342,16 @@ var_clear_vardict (struct variable *v)
 double
 var_force_valid_weight (const struct variable *wv, double w, bool *warn_on_invalid)
 {
-  if (w < 0.0 || (wv && var_is_num_missing (wv, w)))
-    w = 0.0;
-
-  if (w == 0.0 && warn_on_invalid != NULL && *warn_on_invalid)
+  if (w <= 0.0 || (wv ? var_is_num_missing (wv, w) : w == SYSMIS))
     {
-      *warn_on_invalid = false;
-      msg (SW, _("At least one case in the data file had a weight value "
-		 "that was user-missing, system-missing, zero, or "
-		 "negative.  These case(s) were ignored."));
+      w = 0.0;
+      if (warn_on_invalid != NULL && *warn_on_invalid)
+        {
+          *warn_on_invalid = false;
+          msg (SW, _("At least one case in the data file had a weight value "
+                     "that was user-missing, system-missing, zero, or "
+                     "negative.  These case(s) were ignored."));
+        }
     }
 
   return w;
