@@ -110,13 +110,14 @@ struct command
   {
     enum states states;         /* States in which command is allowed. */
     enum flags flags;           /* Other command requirements. */
-    const char *name;		/* Command name. */
-    int (*function) (struct lexer *, struct dataset *);	/* Function to call. */
+    const char *name;                /* Command name. */
+    const char *label;                /* Translated command label. */
+    int (*function) (struct lexer *, struct dataset *);        /* Function to call. */
   };
 
 /* Define the command array. */
-#define DEF_CMD(STATES, FLAGS, NAME, FUNCTION) {STATES, FLAGS, NAME, FUNCTION},
-#define UNIMPL_CMD(NAME, DESCRIPTION) {S_ANY, 0, NAME, NULL},
+#define DEF_CMD(STATES, FLAGS, NAME, LABEL, FUNCTION) {STATES, FLAGS, NAME, LABEL, FUNCTION},
+#define UNIMPL_CMD(NAME, DESCRIPTION) {S_ANY, 0, NAME, NAME, NULL},
 static const struct command commands[] =
   {
 #include "command.def"
@@ -127,7 +128,7 @@ static const struct command commands[] =
 static const size_t n_commands = sizeof commands / sizeof *commands;
 
 static bool in_correct_state (const struct command *, enum cmd_state);
-static void report_state_mismatch (const struct command *, enum cmd_state);
+static char *report_state_mismatch (const struct command *, enum cmd_state);
 static void set_completion_state (enum cmd_state);
 
 /* Command parser. */
@@ -141,7 +142,7 @@ static enum cmd_result do_parse_command (struct lexer *, struct dataset *, enum
    Returns the command's success or failure result. */
 enum cmd_result
 cmd_parse_in_state (struct lexer *lexer, struct dataset *ds,
-		    enum cmd_state state)
+                    enum cmd_state state)
 {
   struct session *session = dataset_session (ds);
   int result;
@@ -162,9 +163,9 @@ cmd_parse (struct lexer *lexer, struct dataset *ds)
 {
   const struct dictionary *dict = dataset_dict (ds);
   return cmd_parse_in_state (lexer, ds,
-			     dataset_has_source (ds) &&
-			     dict_get_n_vars (dict) > 0 ?
-			     CMD_STATE_DATA : CMD_STATE_INITIAL);
+                             dataset_has_source (ds) &&
+                             dict_get_n_vars (dict) > 0 ?
+                             CMD_STATE_DATA : CMD_STATE_INITIAL);
 }
 
 
@@ -172,7 +173,7 @@ cmd_parse (struct lexer *lexer, struct dataset *ds)
    dot. */
 static enum cmd_result
 do_parse_command (struct lexer *lexer,
-		  struct dataset *ds, enum cmd_state state)
+                  struct dataset *ds, enum cmd_state state)
 {
   const struct command *command = NULL;
   size_t nesting_level = SIZE_MAX;
@@ -201,29 +202,36 @@ do_parse_command (struct lexer *lexer,
       goto finish;
     }
 
-  nesting_level = output_open_group (group_item_create_nocopy (
-                                       utf8_to_title (command->name),
-                                       utf8_to_title (command->name)));
+  nesting_level = output_open_group (group_item_create (
+                                       command->name,
+                                       gettext (command->label)));
 
+  int end = n_tokens - 1;
   if (command->function == NULL)
     {
-      msg (SE, _("%s is not yet implemented."), command->name);
+      lex_ofs_error (lexer, 0, end, _("%s is not yet implemented."),
+                     command->name);
       result = CMD_NOT_IMPLEMENTED;
     }
   else if ((command->flags & F_TESTING) && !settings_get_testing_mode ())
     {
-      msg (SE, _("%s may be used only in testing mode."), command->name);
+      lex_ofs_error (lexer, 0, end, _("%s may be used only in testing mode."),
+                     command->name);
       result = CMD_FAILURE;
     }
   else if ((command->flags & F_ENHANCED) && settings_get_syntax () != ENHANCED)
     {
-      msg (SE, _("%s may be used only in enhanced syntax mode."),
-           command->name);
+      lex_ofs_error (lexer, 0, end,
+                     _("%s may be used only in enhanced syntax mode."),
+                     command->name);
       result = CMD_FAILURE;
     }
   else if (!in_correct_state (command, state))
     {
-      report_state_mismatch (command, state);
+      char *message = report_state_mismatch (command, state);
+      lex_ofs_error (lexer, 0, end, "%s", message);
+      free (message);
+
       result = CMD_FAILURE;
     }
   else
@@ -245,13 +253,13 @@ finish:
     result = lex_end_of_command (lexer);
 
   lex_discard_rest_of_command (lexer);
+  if (nesting_level != SIZE_MAX)
+    output_close_groups (nesting_level);
+
   if (result != CMD_EOF && result != CMD_FINISH)
     while (lex_token (lexer) == T_ENDCMD)
       lex_get (lexer);
 
-  if (nesting_level != SIZE_MAX)
-    output_close_groups (nesting_level);
-
   return result;
 }
 
@@ -342,17 +350,18 @@ parse_command_name (struct lexer *lexer, int *n_tokens)
       ds_truncate (&s, ds_length (&s) - 2);
     }
 
+  *n_tokens = (word + 1) + missing_words;
   if (command == NULL)
     {
       if (ds_is_empty (&s))
-        lex_error (lexer, _("expecting command name"));
+        lex_error (lexer, _("Syntax error expecting command name."));
       else
-        msg (SE, _("Unknown command `%s'."), ds_cstr (&s));
+        lex_ofs_error (lexer, 0, *n_tokens - 1,
+                       _("Unknown command `%s'."), ds_cstr (&s));
     }
 
   ds_destroy (&s);
 
-  *n_tokens = (word + 1) + missing_words;
   return command;
 }
 
@@ -364,9 +373,9 @@ in_correct_state (const struct command *command, enum cmd_state state)
   return command->states & (1 << state);
 }
 
-/* Emits an appropriate error message for trying to invoke
+/* Returns an appropriate error message for trying to invoke
    COMMAND in STATE. */
-static void
+static char *
 report_state_mismatch (const struct command *command, enum cmd_state state)
 {
   assert (!in_correct_state (command, state));
@@ -380,56 +389,49 @@ report_state_mismatch (const struct command *command, enum cmd_state state)
         {
           /* One allowed state. */
         case S_INITIAL:
-          msg (SE, _("%s is allowed only before the active dataset has "
-                     "been defined."), command->name);
-          break;
+          return xasprintf (_("%s is allowed only before the active dataset has "
+                              "been defined."), command->name);
         case S_DATA:
-          msg (SE, _("%s is allowed only after the active dataset has "
-                     "been defined."), command->name);
-          break;
+          return xasprintf (_("%s is allowed only after the active dataset has "
+                              "been defined."), command->name);
         case S_INPUT_PROGRAM:
-          msg (SE, _("%s is allowed only inside %s."),
-               command->name, "INPUT PROGRAM");
-          break;
+          return xasprintf (_("%s is allowed only inside %s."),
+                            command->name, "INPUT PROGRAM");
         case S_FILE_TYPE:
-          msg (SE, _("%s is allowed only inside %s."), command->name, "FILE TYPE");
-          break;
+          return xasprintf (_("%s is allowed only inside %s."), command->name, "FILE TYPE");
 
           /* Two allowed states. */
         case S_INITIAL | S_DATA:
           NOT_REACHED ();
         case S_INITIAL | S_INPUT_PROGRAM:
-          msg (SE, _("%s is allowed only before the active dataset has been defined or inside %s."),
-	       command->name, "INPUT PROGRAM");
-          break;
+          return xasprintf (_("%s is allowed only before the active dataset "
+                              "has been defined or inside %s."),
+                            command->name, "INPUT PROGRAM");
         case S_INITIAL | S_FILE_TYPE:
-          msg (SE, _("%s is allowed only before the active dataset has been defined or inside %s."),
-	       command->name, "FILE TYPE");
-          break;
+          return xasprintf (_("%s is allowed only before the active dataset "
+                              "has been defined or inside %s."),
+                            command->name, "FILE TYPE");
         case S_DATA | S_INPUT_PROGRAM:
-          msg (SE, _("%s is allowed only after the active dataset has been defined or inside %s."),
-	       command->name, "INPUT PROGRAM");
-          break;
+          return xasprintf (_("%s is allowed only after the active dataset "
+                              "has been defined or inside %s."),
+                            command->name, "INPUT PROGRAM");
         case S_DATA | S_FILE_TYPE:
-          msg (SE, _("%s is allowed only after the active dataset has been defined or inside %s."),
-	       command->name, "FILE TYPE");
-          break;
+          return xasprintf (_("%s is allowed only after the active dataset "
+                              "has been defined or inside %s."),
+                            command->name, "FILE TYPE");
         case S_INPUT_PROGRAM | S_FILE_TYPE:
-          msg (SE, _("%s is allowed only inside %s or inside %s."), command->name,
-	       "INPUT PROGRAM", "FILE TYPE");
-          break;
+          return xasprintf (_("%s is allowed only inside %s or inside %s."),
+                            command->name, "INPUT PROGRAM", "FILE TYPE");
 
           /* Three allowed states. */
         case S_DATA | S_INPUT_PROGRAM | S_FILE_TYPE:
-          msg (SE, _("%s is allowed only after the active dataset has "
-                     "been defined, inside INPUT PROGRAM, or inside "
-                     "FILE TYPE."), command->name);
-          break;
+          return xasprintf (_("%s is allowed only after the active dataset has "
+                              "been defined, inside INPUT PROGRAM, or inside "
+                              "FILE TYPE."), command->name);
         case S_INITIAL | S_INPUT_PROGRAM | S_FILE_TYPE:
-          msg (SE, _("%s is allowed only before the active dataset has "
-                     "been defined, inside INPUT PROGRAM, or inside "
-                     "FILE TYPE."), command->name);
-          break;
+          return xasprintf (_("%s is allowed only before the active dataset "
+                              "has been defined, inside INPUT PROGRAM, or "
+                              "inside FILE TYPE."), command->name);
         case S_INITIAL | S_DATA | S_FILE_TYPE:
           NOT_REACHED ();
         case S_INITIAL | S_DATA | S_INPUT_PROGRAM:
@@ -445,32 +447,37 @@ report_state_mismatch (const struct command *command, enum cmd_state state)
       break;
 
     case CMD_STATE_INPUT_PROGRAM:
-      msg (SE, _("%s is not allowed inside %s."),
-           command->name, "INPUT PROGRAM");
-      break;
+      return xasprintf (_("%s is not allowed inside %s."),
+                        command->name, "INPUT PROGRAM");
 
     case CMD_STATE_FILE_TYPE:
-      msg (SE, _("%s is not allowed inside %s."), command->name, "FILE TYPE");
-      break;
+      return xasprintf (_("%s is not allowed inside %s."),
+                        command->name, "FILE TYPE");
 
     case CMD_STATE_NESTED_DATA:
     case CMD_STATE_NESTED_INPUT_PROGRAM:
       switch ((int) command->states & S_NESTED_ANY)
         {
         case 0:
-          msg (SE, _("%s is not allowed inside DO IF or LOOP."), command->name);
-          break;
+          return xasprintf (_("%s is not allowed inside DO IF or LOOP."),
+                            command->name);
 
         case S_NESTED_DATA:
-          msg (SE, _("In INPUT PROGRAM, "
-                     "%s is not allowed inside DO IF or LOOP."), command->name);
-          break;
+          return xasprintf (_("In INPUT PROGRAM, "
+                              "%s is not allowed inside DO IF or LOOP."),
+                            command->name);
+
+        case S_NESTED_INPUT_PROGRAM:
+          return xasprintf (_("%s is not allowed inside DO IF or LOOP "
+                              "(except inside INPUT PROGRAM)."),
+                            command->name);
 
         default:
           NOT_REACHED ();
         }
-      break;
     }
+
+  NOT_REACHED ();
 }
 
 /* Command name completion. */
@@ -547,7 +554,9 @@ cmd_erase (struct lexer *lexer, struct dataset *ds UNUSED)
 
   if (settings_get_safer_mode ())
     {
-      msg (SE, _("This command not allowed when the %s option is set."), "SAFER");
+      lex_ofs_error (lexer, 0, 0,
+                     _("This command not allowed when the %s option is set."),
+                     "SAFER");
       return CMD_FAILURE;
     }
 
