@@ -51,9 +51,9 @@ def init_all_types():
 
         # Format types.
         Type.new_atom('format'),
-        Type.new_leaf('ni_format', 'const struct fmt_spec *',
+        Type.new_leaf('ni_format', 'struct fmt_spec',
                       'format', 'f', 'num_input_format'),
-        Type.new_leaf('no_format', 'const struct fmt_spec *',
+        Type.new_leaf('no_format', 'struct fmt_spec',
                       'format', 'f', 'num_output_format'),
 
         # Integer types.
@@ -967,7 +967,7 @@ def usage():
 usage: generate.py -o OUTPUT_TYPE [-i INPUT] [-h] > OUTPUT
   -i INPUT    input file containing definitions (default: operations.def)
   -o OUTPUT   output file type, one of: evaluate.h, evaluate.inc,
-              operations.h, optimize.inc, parse.inc    
+              operations.h, optimize.inc, parse.inc
   -h          display this help message
 """ % argv0)
     sys.exit(0)
