@@ -40,7 +40,8 @@ enum lex_error_mode
     LEX_ERROR_TERMINAL,        /* Discard input line and continue reading. */
     LEX_ERROR_CONTINUE,        /* Continue to next command, except for
                                   cascading failures. */
-    LEX_ERROR_STOP             /* Stop processing. */
+    LEX_ERROR_IGNORE,          /* Continue, even for cascading failures. */
+    LEX_ERROR_STOP,            /* Stop processing. */
   };
 
 /* Reads a single syntax file as a stream of bytes encoded in UTF-8.
@@ -96,6 +97,7 @@ void lex_destroy (struct lexer *);
 
 /* Macros. */
 void lex_define_macro (struct lexer *, struct macro *);
+const struct macro_set *lex_get_macros (const struct lexer *);
 
 /* Files. */
 void lex_include (struct lexer *, struct lex_reader *);
@@ -126,6 +128,7 @@ bool lex_match_id_n (struct lexer *, const char *, size_t n);
 bool lex_match_int (struct lexer *, int);
 bool lex_at_phrase (struct lexer *, const char *s);
 bool lex_match_phrase (struct lexer *, const char *s);
+bool lex_force_match_phrase (struct lexer *, const char *s);
 
 /* Forcible matching functions. */
 bool lex_force_match (struct lexer *, enum token_type) WARN_UNUSED_RESULT;
@@ -136,8 +139,10 @@ bool lex_force_int_range (struct lexer *, const char *name,
 bool lex_force_num (struct lexer *) WARN_UNUSED_RESULT;
 bool lex_force_num_range_closed (struct lexer *, const char *name,
                                  double min, double max) WARN_UNUSED_RESULT;
-bool lex_force_num_range_halfopen (struct lexer *, const char *name,
-                                   double min, double max) WARN_UNUSED_RESULT;
+bool lex_force_num_range_co (struct lexer *, const char *name,
+                             double min, double max) WARN_UNUSED_RESULT;
+bool lex_force_num_range_oc (struct lexer *, const char *name,
+                             double min, double max) WARN_UNUSED_RESULT;
 bool lex_force_num_range_open (struct lexer *, const char *name,
                                double min, double max) WARN_UNUSED_RESULT;
 bool lex_force_id (struct lexer *) WARN_UNUSED_RESULT;
@@ -159,6 +164,7 @@ struct substring lex_next_tokss (const struct lexer *, int n);
 
 /* Looking at the current command, including lookahead and lookbehind. */
 int lex_ofs (const struct lexer *);
+int lex_max_ofs (const struct lexer *);
 const struct token *lex_ofs_token (const struct lexer *, int ofs);
 struct msg_location *lex_ofs_location (const struct lexer *, int ofs0, int ofs1);
 struct msg_point lex_ofs_start_point (const struct lexer *, int ofs);
@@ -173,11 +179,27 @@ bool lex_next_is_from_macro (const struct lexer *, int n);
 const char *lex_get_file_name (const struct lexer *);
 struct msg_location *lex_get_location (const struct lexer *, int n0, int n1);
 const char *lex_get_encoding (const struct lexer *);
+const struct lex_source *lex_source (const struct lexer *);
 
-/* Issuing errors. */
+/* Issuing errors and warnings. */
 void lex_error (struct lexer *, const char *, ...) PRINTF_FORMAT (2, 3);
 void lex_next_error (struct lexer *, int n0, int n1, const char *, ...)
   PRINTF_FORMAT (4, 5);
+void lex_ofs_error (struct lexer *, int ofs0, int ofs1, const char *, ...)
+  PRINTF_FORMAT (4, 5);
+
+void lex_msg (struct lexer *, enum msg_class, const char *, ...)
+  PRINTF_FORMAT (3, 4);
+void lex_next_msg (struct lexer *, enum msg_class, int n0, int n1,
+                   const char *, ...)
+  PRINTF_FORMAT (5, 6);
+void lex_ofs_msg (struct lexer *, enum msg_class, int ofs0, int ofs1,
+                  const char *, ...)
+  PRINTF_FORMAT (5, 6);
+void lex_ofs_msg_valist (struct lexer *lexer, enum msg_class,
+                         int ofs0, int ofs1, const char *format, va_list)
+  PRINTF_FORMAT (5, 0);
+
 int lex_end_of_command (struct lexer *);
 
 void lex_error_expecting (struct lexer *, ...) SENTINEL(0);
@@ -186,20 +208,14 @@ void lex_error_expecting (struct lexer *, ...) SENTINEL(0);
 void lex_error_expecting_valist (struct lexer *, va_list);
 void lex_error_expecting_array (struct lexer *, const char **, size_t n);
 
-void lex_sbc_only_once (const char *);
-void lex_sbc_missing (const char *);
+void lex_sbc_only_once (struct lexer *, const char *);
+void lex_sbc_missing (struct lexer *, const char *);
 
 void lex_spec_only_once (struct lexer *, const char *subcommand,
                          const char *specification);
 void lex_spec_missing (struct lexer *, const char *subcommand,
                        const char *specification);
 
-void lex_error_valist (struct lexer *, const char *, va_list)
-  PRINTF_FORMAT (2, 0);
-void lex_next_error_valist (struct lexer *lexer, int n0, int n1,
-                            const char *format, va_list)
-  PRINTF_FORMAT (4, 0);
-
 /* Error handling. */
 enum segmenter_mode lex_get_syntax_mode (const struct lexer *);
 enum lex_error_mode lex_get_error_mode (const struct lexer *);
@@ -211,7 +227,7 @@ void lex_discard_noninteractive (struct lexer *);
 void lex_set_message_handler (struct lexer *,
                               void (*output_msg) (const struct msg *,
                                                   struct lexer *));
-void lex_source_ref (const struct lex_source *);
+struct lex_source *lex_source_ref (const struct lex_source *);
 void lex_source_unref (struct lex_source *);
 struct substring lex_source_get_line (const struct lex_source *, int line);
 
