@@ -19,6 +19,7 @@
 
 #include <stdbool.h>
 #include <stddef.h>
+#include "data/dict-class.h"
 
 struct pool;
 struct dictionary;
@@ -40,16 +41,16 @@ void var_set_destroy (struct var_set *vs);
 
 enum
   {
-    PV_NONE = 0,		/* No options. */
-    PV_SINGLE = 0001,		/* Restrict to a single name or TO use. */
-    PV_DUPLICATE = 0002,	/* Don't merge duplicates. */
-    PV_APPEND = 0004,		/* Append to existing list. */
-    PV_NO_DUPLICATE = 0010,	/* Error on duplicates. */
-    PV_NUMERIC = 0020,		/* Vars must be numeric. */
-    PV_STRING = 0040,		/* Vars must be string. */
-    PV_SAME_TYPE = 00100,	/* All vars must be the same type. */
-    PV_SAME_WIDTH = 00200,	/* All vars must be the same type and width. */
-    PV_NO_SCRATCH = 00400 	/* Disallow scratch variables. */
+    PV_NONE = 0,                /* No options. */
+    PV_SINGLE = 1 << 0,         /* Restrict to a single name or TO use. */
+    PV_DUPLICATE = 1 << 1,      /* Don't merge duplicates. */
+    PV_APPEND = 1 << 2,         /* Append to existing list. */
+    PV_NO_DUPLICATE = 1 << 3,   /* Error on duplicates. */
+    PV_NUMERIC = 1 << 4,        /* Vars must be numeric. */
+    PV_STRING = 1 << 5,         /* Vars must be string. */
+    PV_SAME_TYPE = 1 << 6,      /* All vars must be the same type. */
+    PV_SAME_WIDTH = 1 << 7,     /* All vars must be the same type and width. */
+    PV_NO_SCRATCH = 1 << 8,     /* Disallow scratch variables. */
   };
 
 struct variable *parse_variable (struct lexer *, const struct dictionary *);
@@ -60,16 +61,17 @@ bool parse_variables_pool (struct lexer *, struct pool *, const struct dictionar
 bool parse_var_set_vars (struct lexer *, const struct var_set *, struct variable ***, size_t *,
                         int opts);
 
-char *parse_DATA_LIST_var (struct lexer *, const struct dictionary *);
+char *parse_DATA_LIST_var (struct lexer *, const struct dictionary *,
+                           enum dict_class);
 bool parse_DATA_LIST_vars (struct lexer *, const struct dictionary *,
                            char ***names, size_t *n, int opts);
 bool parse_DATA_LIST_vars_pool (struct lexer *, const struct dictionary *,
                                 struct pool *,
                                 char ***names, size_t *n, int opts);
 bool parse_mixed_vars (struct lexer *, const struct dictionary *dict,
-		       char ***names, size_t *n, int opts);
+                       char ***names, size_t *n, int opts);
 bool parse_mixed_vars_pool (struct lexer *, const struct dictionary *dict,
-			    struct pool *,
+                            struct pool *,
                            char ***names, size_t *n, int opts);
 
 /* This variable parser supports the unusual situation where set of variables
@@ -82,11 +84,20 @@ struct var_syntax
   {
     char *first;                /* Always nonnull. */
     char *last;                 /* Nonnull for var ranges (e.g. "a TO b"). */
+
+    /* For error reporting.
+
+      This only works if var_syntax_parse() and var_syntax_evaluate() are
+      called while we're parsing the same source file.  That matches the
+      current use case in MATRIX; if that changes, then this will need to
+      switch to use struct msg_location instead. */
+    int first_ofs;
+    int last_ofs;
   };
 void var_syntax_destroy (struct var_syntax *, size_t n);
 
 bool var_syntax_parse (struct lexer *, struct var_syntax **, size_t *);
-bool var_syntax_evaluate (const struct var_syntax *, size_t,
+bool var_syntax_evaluate (struct lexer *, const struct var_syntax *, size_t,
                           const struct dictionary *,
                           struct variable ***, size_t *, int opts);
 
@@ -100,16 +111,16 @@ parse_variable_const (struct lexer *l, const struct dictionary *d)
 
 static inline bool
 parse_variables_const (struct lexer *l, const struct dictionary *d,
-		       const struct variable ***v, size_t *s,
-		       int opts)
+                       const struct variable ***v, size_t *s,
+                       int opts)
 {
   return parse_variables (l, d, (struct variable ***) v, s, opts);
 }
 
 static inline bool
 parse_variables_const_pool (struct lexer *l, struct pool *p,
-			    const struct dictionary *d,
-			    const struct variable ***v, size_t *s, int opts)
+                            const struct dictionary *d,
+                            const struct variable ***v, size_t *s, int opts)
 {
   return parse_variables_pool (l, p, d, (struct variable ***) v, s, opts);
 }
@@ -124,7 +135,7 @@ const_var_set_create_from_dict (const struct dictionary *d)
 
 static inline struct const_var_set *
 const_var_set_create_from_array (const struct variable *const *var,
-				 size_t s)
+                                 size_t s)
 {
   return (struct const_var_set *) var_set_create_from_array ((struct variable *const *) var, s);
 }
@@ -132,10 +143,10 @@ const_var_set_create_from_array (const struct variable *const *var,
 
 static inline bool
 parse_const_var_set_vars (struct lexer *l, const struct const_var_set *vs,
-			  const struct variable ***v, size_t *s, int opts)
+                          const struct variable ***v, size_t *s, int opts)
 {
   return parse_var_set_vars (l, (const struct var_set *) vs,
-			     (struct variable ***) v, s, opts);
+                             (struct variable ***) v, s, opts);
 }
 
 static inline void
@@ -150,16 +161,4 @@ const_var_set_destroy (struct const_var_set *vs)
 bool
 lex_match_variable (struct lexer *lexer, const struct dictionary *dict, const struct variable **var);
 
-struct interaction;
-
-/* Parse an interaction.
-   If not successful return false.
-   Otherwise, a newly created interaction will be placed in IACT.
-   It is the caller's responsibility to destroy this interaction.
- */
-bool
-parse_design_interaction (struct lexer *lexer, const struct dictionary *dict, struct interaction **iact);
-
-
-
 #endif /* variable-parser.h */
