@@ -18,6 +18,7 @@
 #define str_h 1
 
 #include <assert.h>
+#include <limits.h>
 #include <stdarg.h>
 #include <stdbool.h>
 #include <stdint.h>
@@ -30,6 +31,7 @@
 #include "xstrndup.h"
 #include "xvasprintf.h"
 
+#include "gl/verify.h"
 #include "gl/xalloc.h"
 
 /* Miscellaneous. */
@@ -51,8 +53,15 @@ void str_copy_buf_trunc (char *, size_t, const char *, size_t);
 void str_uppercase (char *);
 void str_lowercase (char *);
 
-bool str_format_26adic (unsigned long int number, bool uppercase,
-                        char buffer[], size_t);
+/* Maximum number of digits needed to express ULONG_MAX in 26-adic notation. */
+#define F26ADIC_STRLEN_MAX 14
+verify (ULONG_MAX <= UINT64_MAX);
+
+bool str_format_26adic__ (unsigned long int number, bool uppercase,
+                          char buffer[], size_t);
+void str_format_26adic  (unsigned long int number, bool uppercase,
+                         char buffer[], size_t);
+int str_parse_26adic (const char *str);
 
 void str_ellipsize (struct substring in, char *out, size_t out_size);
 
@@ -92,11 +101,10 @@ struct substring ss_tail (struct substring, size_t);
 /* Constructors and destructor that allocate and deallocate
    memory. */
 struct pool;
-void ss_alloc_substring (struct substring *, struct substring);
+struct substring ss_clone (struct substring);
+struct substring ss_clone_pool (struct substring, struct pool *);
 void ss_alloc_uninit (struct substring *, size_t);
 void ss_realloc (struct substring *, size_t);
-void ss_alloc_substring_pool (struct substring *, struct substring,
-                              struct pool *);
 void ss_alloc_uninit_pool (struct substring *, size_t, struct pool *);
 void ss_dealloc (struct substring *);
 
@@ -118,6 +126,7 @@ void ss_advance (struct substring *, size_t);
 bool ss_match_byte (struct substring *, char);
 int ss_match_byte_in (struct substring *, struct substring);
 bool ss_match_string (struct substring *, const struct substring);
+bool ss_match_string_case (struct substring *, const struct substring);
 int ss_get_byte (struct substring *);
 size_t ss_get_bytes (struct substring *, size_t n, struct substring *);
 bool ss_get_until (struct substring *, char delimiter, struct substring *);
@@ -132,12 +141,15 @@ int ss_at (struct substring, size_t idx);
 int ss_first (struct substring);
 int ss_last (struct substring);
 bool ss_starts_with (struct substring, struct substring prefix);
+bool ss_starts_with_case (struct substring, struct substring prefix);
 bool ss_ends_with (struct substring, struct substring suffix);
+bool ss_ends_with_case (struct substring, struct substring suffix);
 size_t ss_span (struct substring, struct substring skip_set);
 size_t ss_cspan (struct substring, struct substring stop_set);
 size_t ss_find_byte (struct substring, char);
 size_t ss_find_substring (struct substring, struct substring);
 int ss_compare (struct substring, struct substring);
+int ss_compare_rpad (struct substring, struct substring);
 int ss_compare_case (struct substring, struct substring);
 int ss_equals (struct substring, struct substring);
 int ss_equals_case (struct substring, struct substring);
@@ -240,6 +252,7 @@ void ds_put_byte_multiple (struct string *, int ch, size_t);
 void ds_put_unichar (struct string *, ucs4_t uc);
 void ds_put_cstr (struct string *, const char *);
 void ds_put_substring (struct string *, struct substring);
+void ds_put_substring_multiple (struct string *, struct substring, size_t n);
 void ds_put_vformat (struct string *st, const char *, va_list)
      PRINTF_FORMAT (2, 0);
 void ds_put_c_vformat (struct string *st, const char *, va_list)
@@ -258,11 +271,13 @@ char *ds_splice_uninit (struct string *, size_t ofs, size_t old_len,
 /* Other */
 /* calls relocate from gnulib on ST */
 void ds_relocate (struct string *st);
-
+char *relocate_clone (const char *);
+char *relocate_format (const char *, ...)
+  PRINTF_FORMAT (1, 2) MALLOC_LIKE;
 
 void u8_buf_copy_rpad (uint8_t *dst, size_t dst_size,
-		       const uint8_t *src, size_t src_size,
-		       char pad);
+                       const uint8_t *src, size_t src_size,
+                       char pad);
 
 static inline struct substring
 ss_empty (void)
