@@ -29,8 +29,6 @@
 #include "gettext.h"
 #define _(msgid) gettext (msgid)
 
-static const double standard_tick[] = {1, 2, 5, 10};
-
 /*
    Find a set {LOWER, INTERVAL, N_TICKS} such that:
 
@@ -54,39 +52,55 @@ static const double standard_tick[] = {1, 2, 5, 10};
 */
 void
 chart_get_scale (double high, double low,
-		 double *lower, double *interval,
-		 int *n_ticks)
+                 double *lower, double *interval,
+                 int *n_ticks)
 {
-  int i;
-  double fitness = DBL_MAX;
-  double logrange;
-  *n_ticks = 0;
-
   assert (high >= low);
-
-  if ((high - low) < 10 * DBL_MIN) {
-    *n_ticks = 0;
-    *lower = low;
-    *interval = 0.0;
-    return;
-  }
-
-  logrange = floor(log10(high-low));
-
-  /* Find the most pleasing interval */
-  for (i = 1; i < 4; ++i)
+  if ((high - low) < 10 * DBL_MIN)
     {
-      double cinterval = standard_tick[i] * pow(10.0,logrange-1);
-      double clower = floor(low/cinterval) * cinterval;
-      int cnticks = ceil((high - clower) / cinterval)-1;
-      double cfitness = fabs(7.5 - cnticks);
+      *n_ticks = 0;
+      *lower = low;
+      *interval = 0.0;
+      return;
+    }
 
-      if (cfitness < fitness) {
-	fitness = cfitness;
-	*lower = clower;
-	*interval = cinterval;
-	*n_ticks = cnticks;
-      }
+  /* Round down the difference between HIGH and LOW to a power of 10, then
+     divide by 10.  If HIGH - LOW is a power of 10, then BINTERVAL will be
+     (HIGH - LOW) / 10; otherwise, it will be less than (HIGH - LOW) / 10 but
+     more than (HIGH - LOW) / 100.
+
+     for a range of [5.5,9.2], binterval = 0.1;
+     For a range of [0,10], binterval = 1;
+     for a range of [55,92], binterval = 1;
+     for a range of [0,100], binterval = 10;
+     for a range of [555,922], binterval = 10;
+     and so on. */
+  double binterval = pow (10.0, floor (log10 (high - low)) - 1);
+  double fitness = DBL_MAX;
+
+  /* Find the most pleasing interval. */
+  static const double standard_tick[] = {1, 2, 5, 10};
+  for (int i = 0; i < sizeof standard_tick / sizeof *standard_tick; i++)
+    {
+      /* Take a multiple of the basic interval. */
+      double cinterval = standard_tick[i] * binterval;
+
+      /* Make a range by rounding LOW down to the next multiple of CINTERVAL,
+         and HIGH up to the next multiple of CINTERVAL. */
+      double clower = floor (low / cinterval) * cinterval;
+      int cnticks = ceil ((high - clower) / cinterval) - 1;
+
+      /* Compute a score based on considering 7.5 ticks to be ideal. */
+      double cfitness = fabs (7.5 - cnticks);
+
+      /* Choose the lowest score. */
+      if (cfitness < fitness)
+        {
+          fitness = cfitness;
+          *lower = clower;
+          *interval = cinterval;
+          *n_ticks = cnticks;
+        }
     }
 }
 
@@ -142,7 +156,7 @@ gen_pango_markup_scientific_format_string (int n_decimals, int exponent)
  */
 char *
 chart_get_ticks_format (const double lower, const double interval,
-			const unsigned int nticks, double *scale)
+                        const unsigned int nticks, double *scale)
 {
   double logmax = log10(fmax(fabs(lower + (nticks+1)*interval),fabs(lower)));
   double logintv = log10(interval);
@@ -155,42 +169,42 @@ chart_get_ticks_format (const double lower, const double interval,
       nrdecs = MIN(6,(int)(ceil(fabs(logintv))));
       logshift = 0;
       if (logmax < 12.0)
-	format_string = xasprintf("%%.%dlf",nrdecs);
+        format_string = xasprintf("%%.%dlf",nrdecs);
       else
-	format_string = xasprintf("%%lg");
+        format_string = xasprintf("%%lg");
     }
   else if (logmax > 0.0) /*logintv is > 0*/
     {
       if (logintv < 5.0 && logmax < 10.0)
-	{
-	  logshift = 0; /* No scientific format */
-	  nrdecs = 0;
-	  format_string = xstrdup("%.0lf");
-	}
+        {
+          logshift = 0; /* No scientific format */
+          nrdecs = 0;
+          format_string = xstrdup("%.0lf");
+        }
       else
-	{
-	  logshift = (int)logmax;
-	  /* Possible intervals are 0.2Ex, 0.5Ex, 1.0Ex                    */
-	  /* log10(0.2E9) = 8.30, log10(0.5E9) = 8.69, log10(1.0E9) = 9    */
-	  /* 0.2 and 0.5 need one decimal more. For stability subtract 0.1 */
-	  nrdecs = MIN(8,(int)(ceil(logshift-logintv-0.1)));
-	  format_string = gen_pango_markup_scientific_format_string (nrdecs, logshift);
-	}
+        {
+          logshift = (int)logmax;
+          /* Possible intervals are 0.2Ex, 0.5Ex, 1.0Ex                    */
+          /* log10(0.2E9) = 8.30, log10(0.5E9) = 8.69, log10(1.0E9) = 9    */
+          /* 0.2 and 0.5 need one decimal more. For stability subtract 0.1 */
+          nrdecs = MIN(8,(int)(ceil(logshift-logintv-0.1)));
+          format_string = gen_pango_markup_scientific_format_string (nrdecs, logshift);
+        }
     }
   else /* logmax and logintv are < 0 */
     {
       if (logmax > -3.0)
-	{
-	  logshift = 0; /* No scientific format */
-	  nrdecs = MIN(8,(int)(ceil(-logintv)));
-	  format_string = xasprintf("%%.%dlf",nrdecs);
-	}
+        {
+          logshift = 0; /* No scientific format */
+          nrdecs = MIN(8,(int)(ceil(-logintv)));
+          format_string = xasprintf("%%.%dlf",nrdecs);
+        }
       else
-	{
-	  logshift = (int)logmax-1;
-	  nrdecs = MIN(8,(int)(ceil(logshift-logintv-0.1)));
-	  format_string = gen_pango_markup_scientific_format_string (nrdecs, logshift);
-	}
+        {
+          logshift = (int)logmax-1;
+          nrdecs = MIN(8,(int)(ceil(logshift-logintv-0.1)));
+          format_string = gen_pango_markup_scientific_format_string (nrdecs, logshift);
+        }
       }
   *scale = pow(10.0,-(double)logshift);
   return format_string;
