@@ -20,7 +20,7 @@
 
 #include "data/case.h"
 #include "data/casereader.h"
-#include "language/stats/roc.h"
+#include "language/commands/roc.h"
 #include "output/cairo-chart.h"
 
 #include "gettext.h"
@@ -57,15 +57,15 @@ xrchart_draw_roc (const struct chart *chart, cairo_t *cr,
 
       xrchart_vector_start (cr, geom, rv->name);
       for (; (cc = casereader_read (r)) != NULL; case_unref (cc))
-	{
-	  double se = case_num_idx (cc, ROC_TP);
-	  double sp = case_num_idx (cc, ROC_TN);
+        {
+          double se = case_num_idx (cc, ROC_TP);
+          double sp = case_num_idx (cc, ROC_TN);
 
-	  se /= case_num_idx (cc, ROC_FN) + case_num_idx (cc, ROC_TP);
-	  sp /= case_num_idx (cc, ROC_TN) + case_num_idx (cc, ROC_FP);
+          se /= case_num_idx (cc, ROC_FN) + case_num_idx (cc, ROC_TP);
+          sp /= case_num_idx (cc, ROC_TN) + case_num_idx (cc, ROC_FP);
 
-	  xrchart_vector (cr, geom, 1 - sp, se);
-	}
+          xrchart_vector (cr, geom, 1 - sp, se);
+        }
       xrchart_vector_end (cr, geom);
       casereader_destroy (r);
     }
