@@ -28,6 +28,7 @@ struct output_iterator;
 struct string_map;
 struct file_handle;
 struct page_setup;
+struct driver_options;
 
 /* A configured output driver. */
 struct output_driver
@@ -37,16 +38,14 @@ struct output_driver
     enum settings_output_devices device_type; /* One of SETTINGS_DEVICE_*. */
   };
 
-void output_driver_init (struct output_driver *,
-                         const struct output_driver_class *,
-                         const char *, enum settings_output_devices);
-
 void output_driver_destroy (struct output_driver *);
 
 const char *output_driver_get_name (const struct output_driver *);
 
 char *output_driver_substitute_heading_vars (const char *, int page_number);
 
+struct output_driver *output_driver_find (const struct output_driver_class *);
+
 /* One kind of output driver.
 
    Output driver implementations must not call msg() to report errors.  This
@@ -117,7 +116,7 @@ struct output_driver_factory
        is desirable). */
     struct output_driver *(*create) (struct file_handle *,
                                      enum settings_output_devices type,
-                                     struct string_map *options);
+                                     struct driver_options *);
   };
 
 #endif /* output/driver-provider.h */
