@@ -25,6 +25,8 @@
 #include "libpspp/hmap.h"
 #include "output/table.h"
 
+struct ccase;
+struct dictionary;
 struct pivot_value;
 struct variable;
 union value;
@@ -177,9 +179,8 @@ enum pivot_axis_type
   {
     PIVOT_AXIS_LAYER,
     PIVOT_AXIS_ROW,
-    PIVOT_AXIS_COLUMN,
-
-    PIVOT_N_AXES
+    PIVOT_AXIS_COLUMN
+#define PIVOT_N_AXES 3
   };
 
 const char *pivot_axis_type_to_string (enum pivot_axis_type);
@@ -281,6 +282,55 @@ void pivot_dimension_destroy (struct pivot_dimension *);
 void pivot_dimension_dump (const struct pivot_dimension *,
                            const struct pivot_table *, int indentation);
 
+/* Split file handling with pivot tables.
+
+   When SPLIT FILE is in effect with the LAYERED option, values for the split
+   file variables need to be incorporated into pivot table output.  These
+   functions make that easier.
+
+   To use them:
+
+   1. After adding the rest of the dimensions to an output pivot table, call
+      pivot_splits_create().  If there are any and LAYERED mode is in use, then
+      pivot_splits_create() will add a dimension for each split file
+      variable and return a structure.  Otherwise, it returns NULL.
+
+   2. Before adding data to the pivot table for each SPLIT FILE group, call
+      pivot_splits_new_split(), passing in an example case from the group (the
+      first or last case is fine).  This will the split file handler add
+      categories for the group to the split dimensions.
+
+      pivot_splits_new_split() does nothing if given a null pivot_splits, so
+      it's fine to call it unconditionally.
+
+   3. Use pivot_splits_put*(), instead of pivot_table_put*(), to add data to
+      the pivot table.  These functions automatically add the current group
+      leaf indexes after the indexes passed in, as a convenience.
+
+      These functions still work fine if given a null pivot_splits, so it's
+      fine to use them in all cases.
+
+   4. Destroy the pivot_splits with pivot_splits_destroy() when the pivot table
+      has been fully constructed. */
+
+struct pivot_splits *pivot_splits_create (struct pivot_table *,
+                                          enum pivot_axis_type,
+                                          const struct dictionary *);
+void pivot_splits_destroy (struct pivot_splits *);
+
+void pivot_splits_new_split (struct pivot_splits *, const struct ccase *);
+
+void pivot_splits_put1 (struct pivot_splits *, struct pivot_table *,
+                        size_t idx1, struct pivot_value *);
+void pivot_splits_put2 (struct pivot_splits *, struct pivot_table *,
+                        size_t idx1, size_t idx2, struct pivot_value *);
+void pivot_splits_put3 (struct pivot_splits *, struct pivot_table *,
+                        size_t idx1, size_t idx2, size_t idx3,
+                        struct pivot_value *);
+void pivot_splits_put4 (struct pivot_splits *, struct pivot_table *,
+                        size_t idx1, size_t idx2, size_t idx3, size_t idx4,
+                        struct pivot_value *);
+
 /* A pivot_category is a leaf (a category) or a group:
 
    - For a leaf, neither index is SIZE_MAX.
@@ -362,7 +412,7 @@ void pivot_category_destroy (struct pivot_category *);
 #define PIVOT_RC_RESIDUAL ("RC_RESIDUAL")
 #define PIVOT_RC_COUNT ("RC_COUNT")
 
-bool pivot_result_class_change (const char *, const struct fmt_spec *);
+bool pivot_result_class_change (const char *, struct fmt_spec);
 bool is_pivot_result_class (const char *);
 
 /* Styling for a pivot table.
@@ -378,11 +428,20 @@ struct pivot_table_look
     int ref_cnt;
 
     char *name;                 /* May be null. */
+    char *file_name;            /* May be null. */
 
-    /* General properties. */
+    /* General properties.
+
+       col_heading_width_range and row_heading_width_range is minimum and
+       maximum width of columns based on their column heading labels, in 1/96"
+       units.  row_heading_width_range is for columns in the row headings and
+       corner, and col_heading_width_range is for columns in the column
+       headings.
+    */
     bool omit_empty;
     bool row_labels_in_corner;
-    int width_ranges[TABLE_N_AXES][2];      /* In 1/96" units. */
+    int row_heading_width_range[2];
+    int col_heading_width_range[2];
 
     /* Footnote display settings. */
     bool show_numeric_markers;
@@ -431,11 +490,17 @@ struct pivot_table
     bool show_grid_lines;
     bool show_title;
     bool show_caption;
-    size_t *current_layer; /* axes[PIVOT_AXIS_LAYER].n_dimensions elements. */
     enum settings_value_show show_values;
     enum settings_value_show show_variables;
     struct fmt_spec weight_format;
 
+    /* Current layer indexes, with axes[PIVOT_AXIS_LAYER].n_dimensions
+       elements.  current_layer[i] is an offset into
+       axes[PIVOT_AXIS_LAYER].dimensions[i]->data_leaves[], EXCEPT that a
+       dimension can have zero leaves, in which case current_layer[i] is zero
+       and there's no corresponding leaf. */
+    size_t *current_layer;
+
     /* Column and row sizing and page breaks.
        sizing[TABLE_HORZ] is for columns, sizing[TABLE_VERT] is for rows. */
     struct pivot_table_sizing sizing[TABLE_N_AXES];
@@ -512,8 +577,7 @@ void pivot_table_set_look (struct pivot_table *,
 /* Format of PIVOT_RC_COUNT cells. */
 void pivot_table_set_weight_var (struct pivot_table *,
                                  const struct variable *);
-void pivot_table_set_weight_format (struct pivot_table *,
-                                    const struct fmt_spec *);
+void pivot_table_set_weight_format (struct pivot_table *, struct fmt_spec);
 
 /* Query. */
 bool pivot_table_is_empty (const struct pivot_table *);
@@ -582,6 +646,9 @@ size_t *pivot_table_enumerate_axis (const struct pivot_table *,
 void pivot_table_assign_label_depth (struct pivot_table *);
 
 void pivot_table_dump (const struct pivot_table *, int indentation);
+void pivot_category_dump (const struct pivot_category *c,
+                          const struct pivot_table *pt, int indentation);
+
 
 /* pivot_value. */
 
@@ -740,7 +807,7 @@ struct pivot_value *pivot_value_new_integer (double);
 struct pivot_value *pivot_value_new_var_value (
   const struct variable *, const union value *);
 struct pivot_value *pivot_value_new_value (const union value *, int width,
-                                           const struct fmt_spec *,
+                                           struct fmt_spec,
                                            const char *encoding);
 
 /* Values from variable names. */
@@ -771,7 +838,6 @@ void pivot_value_set_rc (const struct pivot_table *, struct pivot_value *,
 /* Converting a pivot_value to a string for display. */
 char *pivot_value_to_string (const struct pivot_value *,
                              const struct pivot_table *);
-char *pivot_value_to_string_defaults (const struct pivot_value *);
 bool pivot_value_format (const struct pivot_value *,
                          const struct pivot_table *, struct string *);
 bool pivot_value_format_body (const struct pivot_value *,
