@@ -203,7 +203,7 @@ spv_map_insert (struct hmap *map, double from, const char *to,
       else
         {
           union value v = { .f = mapping->to.d };
-          mapping->to.s = data_out_stretchy (&v, NULL, format,
+          mapping->to.s = data_out_stretchy (&v, NULL, *format,
                                              settings_get_fmt_settings (),
                                              NULL);
           mapping->to.width = strlen (mapping->to.s);
@@ -808,7 +808,7 @@ decode_spvdx_source_variable (const struct spvxml_node *node,
             if (label_series->values[i].width < 0)
               {
                 union value v = { .f = label_series->values[i].d };
-                dest = data_out_stretchy (&v, "UTF-8", &s->format,
+                dest = data_out_stretchy (&v, "UTF-8", s->format,
                                           settings_get_fmt_settings (), NULL);
               }
             else
@@ -1793,8 +1793,8 @@ decode_spvdx_table (const struct spvdx_visualization *v, const char *subtype,
                   &min_width, &max_width, &n)
           && v->graph->cell_style->width[n] == '\0')
         {
-          table->look->width_ranges[TABLE_HORZ][0] = min_width;
-          table->look->width_ranges[TABLE_HORZ][1] = max_width;
+          table->look->col_heading_width_range[0] = min_width;
+          table->look->col_heading_width_range[1] = max_width;
         }
     }
 
@@ -1893,10 +1893,10 @@ decode_spvdx_table (const struct spvdx_visualization *v, const char *subtype,
 
       if (!progress)
         {
-          free (nodes);
           error = xasprintf ("Table has %zu variables with circular or "
                              "unresolved references, including variable %s.",
                              n_nodes, nodes[0]->id);
+          free (nodes);
           goto exit;
         }
     }
