@@ -28,7 +28,6 @@
 #include "output/spv/structure-xml-parser.h"
 #include "output/spv/tlo-parser.h"
 #include "output/pivot-table.h"
-#include "output/table.h"
 
 #include "gl/read-file.h"
 #include "gl/xalloc.h"
@@ -126,19 +125,21 @@ pivot_border_from_name (const char *name)
 
 char * WARN_UNUSED_RESULT
 spv_table_look_decode (const struct spvsx_table_properties *in,
+                       const char *file_name,
                        struct pivot_table_look **outp)
 {
   struct pivot_table_look *out = pivot_table_look_new_builtin_default ();
   char *error = NULL;
 
   out->name = xstrdup_if_nonnull (in->name);
+  out->file_name = xstrdup_if_nonnull (file_name);
 
   const struct spvsx_general_properties *g = in->general_properties;
   out->omit_empty = g->hide_empty_rows != 0;
-  out->width_ranges[TABLE_HORZ][0] = optional_pt (g->minimum_column_width, -1);
-  out->width_ranges[TABLE_HORZ][1] = optional_pt (g->maximum_column_width, -1);
-  out->width_ranges[TABLE_VERT][0] = optional_pt (g->minimum_row_width, -1);
-  out->width_ranges[TABLE_VERT][1] = optional_pt (g->maximum_row_width, -1);
+  out->col_heading_width_range[0] = optional_pt (g->minimum_column_width, -1);
+  out->col_heading_width_range[1] = optional_pt (g->maximum_column_width, -1);
+  out->row_heading_width_range[0] = optional_pt (g->minimum_row_width, -1);
+  out->row_heading_width_range[1] = optional_pt (g->maximum_row_width, -1);
   out->row_labels_in_corner
     = g->row_dimension_labels != SPVSX_ROW_DIMENSION_LABELS_NESTED;
 
@@ -381,17 +382,17 @@ tlo_decode (const struct tlo_table_look *in)
   out->row_labels_in_corner = !in->tl->nested_row_labels;
   if (in->v2_styles)
     {
-      out->width_ranges[TABLE_HORZ][0] = in->v2_styles->min_col_width;
-      out->width_ranges[TABLE_HORZ][1] = in->v2_styles->max_col_width;
-      out->width_ranges[TABLE_VERT][0] = in->v2_styles->min_row_height;
-      out->width_ranges[TABLE_VERT][1] = in->v2_styles->max_row_height;
+      out->col_heading_width_range[0] = in->v2_styles->min_col_heading_width;
+      out->col_heading_width_range[1] = in->v2_styles->max_col_heading_width;
+      out->row_heading_width_range[0] = in->v2_styles->min_row_heading_width;
+      out->row_heading_width_range[1] = in->v2_styles->max_row_heading_width;
     }
   else
     {
-      out->width_ranges[TABLE_HORZ][0] = 36;
-      out->width_ranges[TABLE_HORZ][1] = 72;
-      out->width_ranges[TABLE_VERT][0] = 36;
-      out->width_ranges[TABLE_VERT][1] = 120;
+      out->col_heading_width_range[0] = 36;
+      out->col_heading_width_range[1] = 72;
+      out->row_heading_width_range[0] = 36;
+      out->row_heading_width_range[1] = 120;
     }
 
   out->show_numeric_markers = flags & 0x04;
@@ -530,7 +531,7 @@ spv_table_look_read (const char *filename, struct pivot_table_look **outp)
       char *error = spvxml_context_finish (&ctx, &tp->node_);
 
       if (!error)
-        error = spv_table_look_decode (tp, outp);
+        error = spv_table_look_decode (tp, filename, outp);
 
       spvsx_free_table_properties (tp);
       xmlFreeDoc (doc);
@@ -622,11 +623,12 @@ spv_table_look_write (const char *filename, const struct pivot_table_look *look)
 
   start_elem (xml, "generalProperties");
   write_attr_bool (xml, "hideEmptyRows", look->omit_empty);
-  const int (*wr)[2] = look->width_ranges;
-  write_attr_format (xml, "maximumColumnWidth", "%d", wr[TABLE_HORZ][1]);
-  write_attr_format (xml, "maximumRowWidth", "%d", wr[TABLE_VERT][1]);
-  write_attr_format (xml, "minimumColumnWidth", "%d", wr[TABLE_HORZ][0]);
-  write_attr_format (xml, "minimumRowWidth", "%d", wr[TABLE_VERT][0]);
+  const int *chwr = look->col_heading_width_range;
+  const int *rhwr = look->row_heading_width_range;
+  write_attr_format (xml, "maximumColumnWidth", "%d", chwr[1]);
+  write_attr_format (xml, "maximumRowWidth", "%d", rhwr[1]);
+  write_attr_format (xml, "minimumColumnWidth", "%d", chwr[0]);
+  write_attr_format (xml, "minimumRowWidth", "%d", rhwr[0]);
   write_attr (xml, "rowDimensionLabels",
               look->row_labels_in_corner ? "inCorner" : "nested");
   end_elem (xml);
@@ -647,8 +649,8 @@ spv_table_look_write (const char *filename, const struct pivot_table_look *look)
 
       start_elem (xml, pivot_area_names[a]);
       if (a == PIVOT_AREA_DATA
-          && (!cell_color_equal (&font->fg[0], &font->fg[1])
-              || !cell_color_equal (&font->bg[0], &font->bg[1])))
+          && (!cell_color_equal (font->fg[0], font->fg[1])
+              || !cell_color_equal (font->bg[0], font->bg[1])))
         {
           write_attr_color (xml, "alternatingColor", &font->bg[1]);
           write_attr_color (xml, "alternatingTextColor", &font->fg[1]);
