@@ -321,6 +321,9 @@ decode_page_paragraph (const struct spvsx_page_paragraph *page_paragraph,
 {
   memset (ph, 0, sizeof *ph);
 
+  if (!page_paragraph)
+    return;
+
   const struct spvsx_page_paragraph_text *page_paragraph_text
     = page_paragraph->page_paragraph_text;
   if (!page_paragraph_text)
@@ -516,7 +519,7 @@ spv_read_table_item (struct zip_reader *zip,
     {
       struct pivot_table_look *look;
       error = (table->table_properties
-               ? spv_table_look_decode (table->table_properties, &look)
+               ? spv_table_look_decode (table->table_properties, NULL, &look)
                : xstrdup ("Legacy table lacks tableProperties"));
       if (!error)
         {
@@ -882,15 +885,13 @@ spv_decode_fmt_spec (uint32_t u32, struct fmt_spec *out)
   uint8_t w = u32 >> 8;
   uint8_t d = u32;
 
-  msg_disable ();
   *out = (struct fmt_spec) { .type = FMT_F, .w = w, .d = d };
   bool ok = raw_type >= 40 || fmt_from_io (raw_type, &out->type);
   if (ok)
     {
       fmt_fix_output (out);
-      ok = fmt_check_width_compat (out, 0);
+      ok = fmt_check_width_compat (*out, 0);
     }
-  msg_enable ();
 
   if (!ok)
     {
