@@ -20,8 +20,10 @@
 
 #include "builder-wrapper.h"
 
+#include "libpspp/str.h"
 
-GtkBuilder *
+
+static GtkBuilder *
 builder_new_real (const gchar *name)
 {
   GtkBuilder *builder = gtk_builder_new ();
@@ -36,6 +38,16 @@ builder_new_real (const gchar *name)
   return builder;
 }
 
+GtkBuilder *
+builder_new (const gchar *name)
+{
+  char *full_name = relocate_format ("%s/%s", PKGDATADIR, name);
+  GtkBuilder *builder = builder_new_real (full_name);
+  free (full_name);
+
+  return builder;
+}
+
 GObject *
 get_object_assert (GtkBuilder *builder, const gchar *name, GType type)
 {
@@ -49,7 +61,7 @@ get_object_assert (GtkBuilder *builder, const gchar *name, GType type)
   else if (! g_type_is_a (G_OBJECT_TYPE (o), type))
    {
      g_critical ("Object `%s' was expected to have type %s, but in fact has type %s",
-	name, g_type_name (type), G_OBJECT_TYPE_NAME (o));
+        name, g_type_name (type), G_OBJECT_TYPE_NAME (o));
    }
 
   return o;
