@@ -33,8 +33,9 @@
 
 #include "psppire-data-store.h"
 #include "t-test-options.h"
-#include "src/language/stats/chart-category.h"
-#include "src/language/stats/aggregate.h"
+#include "src/language/commands/chart-category.h"
+#include "src/language/commands/aggregate.h"
+#include "libpspp/llx.h"
 
 const GEnumValue align[1];
 const GEnumValue measure[1];
@@ -70,8 +71,10 @@ psppire_data_store_value_to_string (gpointer unused, PsppireDataStore *store, gi
 
 gboolean
 psppire_data_store_string_to_value (GtkTreeModel *model, gint col, gint row,
-				    const gchar *in, GValue *out)
+                                    const gchar *in, GValue *out)
 {
   assert (0);
   return FALSE;
 }
+
+const struct llx_manager llx_malloc_mgr =  {NULL, NULL, NULL};
