@@ -50,14 +50,14 @@ static void psppire_data_store_finalize        (GObject           *object);
 static void psppire_data_store_dispose        (GObject           *object);
 
 static gboolean psppire_data_store_insert_case (PsppireDataStore *ds,
-						struct ccase *cc,
-						casenumber posn);
+                                                struct ccase *cc,
+                                                casenumber posn);
 
 
 static gboolean psppire_data_store_data_in (PsppireDataStore *ds,
-					    casenumber casenum, gint idx,
-					    struct substring input,
-					    const struct fmt_spec *fmt);
+                                            casenumber casenum, gint idx,
+                                            struct substring input,
+                                            struct fmt_spec);
 
 static GObjectClass *parent_class = NULL;
 
@@ -73,7 +73,7 @@ static guint signals [n_SIGNALS];
 
 static gint
 __tree_model_iter_n_children (GtkTreeModel *tree_model,
-			     GtkTreeIter *iter)
+                             GtkTreeIter *iter)
 {
   PsppireDataStore *store  = PSPPIRE_DATA_STORE (tree_model);
 
@@ -104,9 +104,9 @@ __tree_model_get_n_columns (GtkTreeModel *tree_model)
 
 static gboolean
 __iter_nth_child (GtkTreeModel *tree_model,
-		  GtkTreeIter *iter,
-		  GtkTreeIter *parent,
-		  gint n)
+                  GtkTreeIter *iter,
+                  GtkTreeIter *parent,
+                  gint n)
 {
   PsppireDataStore *store  = PSPPIRE_DATA_STORE (tree_model);
 
@@ -130,23 +130,23 @@ __iter_nth_child (GtkTreeModel *tree_model,
    ROW, for MODEL.  Returns TRUE if successful. */
 gboolean
 psppire_data_store_string_to_value (GtkTreeModel *model, gint col, gint row,
-				    const gchar *in, GValue *out)
+                                    const gchar *in, GValue *out)
 {
   PsppireDataStore *store = PSPPIRE_DATA_STORE (model);
 
   while (col >= psppire_dict_get_n_vars (store->dict))
     {
       const struct variable *var =
-	psppire_dict_insert_variable (store->dict,
-				      psppire_dict_get_n_vars (store->dict),
-				      NULL);
+        psppire_dict_insert_variable (store->dict,
+                                      psppire_dict_get_n_vars (store->dict),
+                                      NULL);
       g_return_val_if_fail (var, FALSE);
     }
 
   const struct variable *variable = psppire_dict_get_variable (store->dict, col);
   g_return_val_if_fail (variable, FALSE);
 
-  const struct fmt_spec *fmt = var_get_print_format (variable);
+  struct fmt_spec fmt = var_get_print_format (variable);
 
   int width = var_get_width (variable);
 
@@ -158,13 +158,13 @@ psppire_data_store_string_to_value (GtkTreeModel *model, gint col, gint row,
     {
       vp = val_labs_find_value (value_labels, in);
       if (vp)
-	value_copy (&val, vp, width);
+        value_copy (&val, vp, width);
     }
   char *xx = NULL;
   if (vp == NULL)
     {
       xx = data_in (ss_cstr (in), psppire_dict_encoding (store->dict),
-		    fmt->type, settings_get_fmt_settings (),
+                    fmt.type, settings_get_fmt_settings (),
                     &val, width, "UTF-8");
     }
 
@@ -184,7 +184,7 @@ unlabeled_value (PsppireDataStore *store, const struct variable *variable, const
       var_is_value_missing (variable, val) == MV_SYSTEM)
     return g_strdup ("");
 
-  const struct fmt_spec *fmt = var_get_print_format (variable);
+  struct fmt_spec fmt = var_get_print_format (variable);
   return value_to_text__ (*val, fmt, psppire_dict_encoding (store->dict));
 }
 
@@ -233,9 +233,9 @@ psppire_data_store_value_to_string_with_labels (gpointer unused, PsppireDataStor
 
 static void
 __get_value (GtkTreeModel *tree_model,
-	     GtkTreeIter *iter,
-	     gint column,
-	     GValue *value)
+             GtkTreeIter *iter,
+             gint column,
+             GValue *value)
 {
   PsppireDataStore *store  = PSPPIRE_DATA_STORE (tree_model);
 
@@ -253,7 +253,7 @@ __get_value (GtkTreeModel *tree_model,
 
   g_value_init (value, G_TYPE_VARIANT);
 
-  const union value *val = case_data_idx (cc, var_get_case_index (variable));
+  const union value *val = case_data_idx (cc, var_get_dict_index (variable));
 
   GVariant *vv = value_variant_new (val, var_get_width (variable));
 
@@ -282,8 +282,8 @@ __tree_model_init (GtkTreeModelIface *iface)
 }
 
 G_DEFINE_TYPE_WITH_CODE (PsppireDataStore, psppire_data_store, G_TYPE_OBJECT,
-			 G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL,
-						__tree_model_init))
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL,
+                                                __tree_model_init))
 
 static void
 psppire_data_store_class_init (PsppireDataStoreClass *class)
@@ -298,27 +298,27 @@ psppire_data_store_class_init (PsppireDataStoreClass *class)
 
   signals [ITEMS_CHANGED] =
     g_signal_new ("items-changed",
-		  G_TYPE_FROM_CLASS (class),
-		  G_SIGNAL_RUN_FIRST,
-		  0,
-		  NULL, NULL,
-		  psppire_marshal_VOID__UINT_UINT_UINT,
-		  G_TYPE_NONE,
-		  3,
-		  G_TYPE_UINT,  /* Index of the start of the change */
-		  G_TYPE_UINT,  /* The number of items deleted */
-		  G_TYPE_UINT); /* The number of items inserted */
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_FIRST,
+                  0,
+                  NULL, NULL,
+                  psppire_marshal_VOID__UINT_UINT_UINT,
+                  G_TYPE_NONE,
+                  3,
+                  G_TYPE_UINT,  /* Index of the start of the change */
+                  G_TYPE_UINT,  /* The number of items deleted */
+                  G_TYPE_UINT); /* The number of items inserted */
 
   signals [CASE_CHANGED] =
     g_signal_new ("case-changed",
-		  G_TYPE_FROM_CLASS (class),
-		  G_SIGNAL_RUN_FIRST,
-		  0,
-		  NULL, NULL,
-		  g_cclosure_marshal_VOID__INT,
-		  G_TYPE_NONE,
-		  1,
-		  G_TYPE_INT);
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_FIRST,
+                  0,
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__INT,
+                  G_TYPE_NONE,
+                  1,
+                  G_TYPE_INT);
 }
 
 
@@ -332,7 +332,7 @@ psppire_data_store_get_case_count (const PsppireDataStore *store)
 size_t
 psppire_data_store_get_value_count (const PsppireDataStore *store)
 {
-  return psppire_dict_get_n_values (store->dict);
+  return psppire_dict_get_n_vars (store->dict);
 }
 
 const struct caseproto *
@@ -352,27 +352,36 @@ psppire_data_store_init (PsppireDataStore *data_store)
 
 
 static void
-psppire_data_store_delete_value (PsppireDataStore *store, gint case_index)
+psppire_data_store_delete_values (PsppireDataStore *store, gint case_index,
+                                  guint n)
 {
   g_return_if_fail (store->datasheet);
   g_return_if_fail (case_index < datasheet_get_n_columns (store->datasheet));
 
-  datasheet_delete_columns (store->datasheet, case_index, 1);
-  datasheet_insert_column (store->datasheet, NULL, -1, case_index);
+  datasheet_delete_columns (store->datasheet, case_index, n);
 }
 
 
 /*
-   A callback which occurs after a variable has been deleted.
+   A callback which occurs after variables have been deleted.
  */
 static void
-delete_variable_callback (GObject *obj, const struct variable *var UNUSED,
-                          gint dict_index, gint case_index,
-                          gpointer data)
+delete_variables_callback (GObject *obj, gint dict_index, unsigned int n, gpointer data)
 {
   PsppireDataStore *store  = PSPPIRE_DATA_STORE (data);
 
-  psppire_data_store_delete_value (store, case_index);
+  psppire_data_store_delete_values (store, dict_index, n);
+}
+
+/*
+   A callback which occurs after variables have been moved.
+ */
+static void
+move_variable_callback (GObject *obj, gint new_dict_index, int old_dict_index, gpointer data)
+{
+  PsppireDataStore *store  = PSPPIRE_DATA_STORE (data);
+
+  datasheet_move_columns (store->datasheet, old_dict_index, new_dict_index, 1);
 }
 
 struct resize_datum_aux
@@ -388,11 +397,11 @@ resize_datum (const union value *old, union value *new, const void *aux_)
   const struct resize_datum_aux *aux = aux_;
   int new_width = var_get_width (aux->new_variable);
   const char *enc = dict_get_encoding (aux->dict);
-  const struct fmt_spec *newfmt = var_get_print_format (aux->new_variable);
+  struct fmt_spec newfmt = var_get_print_format (aux->new_variable);
   char *s = data_out (old, enc, var_get_print_format (aux->old_variable),
                       settings_get_fmt_settings ());
-  enum fmt_type type = (fmt_usable_for_input (newfmt->type)
-                        ? newfmt->type
+  enum fmt_type type = (fmt_usable_for_input (newfmt.type)
+                        ? newfmt.type
                         : FMT_DOLLAR);
   free (data_in (ss_cstr (s), enc, type, settings_get_fmt_settings (),
                  new, new_width, enc));
@@ -401,14 +410,14 @@ resize_datum (const union value *old, union value *new, const void *aux_)
 
 static void
 variable_changed_callback (GObject *obj, gint var_num, guint what, const struct variable *oldvar,
-			   gpointer data)
+                           gpointer data)
 {
   PsppireDataStore *store  = PSPPIRE_DATA_STORE (data);
   struct variable *variable = psppire_dict_get_variable (store->dict, var_num);
 
   if (what & VAR_TRAIT_WIDTH)
     {
-      int posn = var_get_case_index (variable);
+      int posn = var_get_dict_index (variable);
       struct resize_datum_aux aux;
       aux.old_variable = oldvar;
       aux.new_variable = variable;
@@ -430,7 +439,7 @@ insert_variable_callback (GObject *obj, gint var_num, gpointer data)
   store  = PSPPIRE_DATA_STORE (data);
 
   variable = psppire_dict_get_variable (store->dict, var_num);
-  posn = var_get_case_index (variable);
+  posn = var_get_dict_index (variable);
   psppire_data_store_insert_value (store, var_get_width (variable), posn);
 }
 
@@ -455,7 +464,7 @@ psppire_data_store_new (PsppireDict *dict)
 
 void
 psppire_data_store_set_reader (PsppireDataStore *ds,
-			       struct casereader *reader)
+                               struct casereader *reader)
 {
   gint i;
   gint old_n = 0;
@@ -472,11 +481,11 @@ psppire_data_store_set_reader (PsppireDataStore *ds,
   if (ds->dict)
     for (i = 0 ; i < n_dict_signals; ++i)
       {
-	if (ds->dict_handler_id [i] > 0)
-	  {
-	    g_signal_handler_unblock (ds->dict,
-				      ds->dict_handler_id[i]);
-	  }
+        if (ds->dict_handler_id [i] > 0)
+          {
+            g_signal_handler_unblock (ds->dict,
+                                      ds->dict_handler_id[i]);
+          }
       }
 
   g_signal_emit (ds, signals[ITEMS_CHANGED], 0, 0, old_n, new_n);
@@ -500,8 +509,8 @@ psppire_data_store_set_dictionary (PsppireDataStore *data_store, PsppireDict *di
   if (data_store->dict)
     for (i = 0 ; i < n_dict_signals; ++i)
       {
-	g_signal_handler_disconnect (data_store->dict,
-				     data_store->dict_handler_id[i]);
+        g_signal_handler_disconnect (data_store->dict,
+                                     data_store->dict_handler_id[i]);
       }
 
   data_store->dict = dict;
@@ -510,19 +519,24 @@ psppire_data_store_set_dictionary (PsppireDataStore *data_store, PsppireDict *di
     {
 
       data_store->dict_handler_id [VARIABLE_INSERTED] =
-	g_signal_connect (dict, "variable-inserted",
-			  G_CALLBACK (insert_variable_callback),
-			  data_store);
+        g_signal_connect (dict, "variable-inserted",
+                          G_CALLBACK (insert_variable_callback),
+                          data_store);
 
-      data_store->dict_handler_id [VARIABLE_DELETED] =
-	g_signal_connect (dict, "variable-deleted",
-			  G_CALLBACK (delete_variable_callback),
-			  data_store);
+      data_store->dict_handler_id [VARIABLES_DELETED] =
+        g_signal_connect (dict, "variables-deleted",
+                          G_CALLBACK (delete_variables_callback),
+                          data_store);
+
+      data_store->dict_handler_id [VARIABLE_MOVED] =
+        g_signal_connect (dict, "variable-moved",
+                          G_CALLBACK (move_variable_callback),
+                          data_store);
 
       data_store->dict_handler_id [VARIABLE_CHANGED] =
-	g_signal_connect (dict, "variable-changed",
-			  G_CALLBACK (variable_changed_callback),
-			  data_store);
+        g_signal_connect (dict, "variable-changed",
+                          G_CALLBACK (variable_changed_callback),
+                          data_store);
     }
 
 
@@ -532,11 +546,11 @@ psppire_data_store_set_dictionary (PsppireDataStore *data_store, PsppireDict *di
   if (data_store->dict)
     for (i = 0 ; i < n_dict_signals; ++i)
       {
-	if (data_store->dict_handler_id [i] > 0)
-	  {
-	    g_signal_handler_block (data_store->dict,
-				    data_store->dict_handler_id[i]);
-	  }
+        if (data_store->dict_handler_id [i] > 0)
+          {
+            g_signal_handler_block (data_store->dict,
+                                    data_store->dict_handler_id[i]);
+          }
       }
 }
 
@@ -599,8 +613,8 @@ psppire_data_store_insert_new_case (PsppireDataStore *ds, casenumber posn)
 
 gboolean
 psppire_data_store_get_value (PsppireDataStore *store,
-			      glong row, const struct variable *var,
-			      union value *val)
+                              glong row, const struct variable *var,
+                              union value *val)
 {
   g_return_val_if_fail (store != NULL, FALSE);
   g_return_val_if_fail (store->datasheet != NULL, FALSE);
@@ -611,7 +625,7 @@ psppire_data_store_get_value (PsppireDataStore *store,
 
   int width = var_get_width (var);
   value_init (val, width);
-  datasheet_get_value (store->datasheet, row, var_get_case_index (var), val);
+  datasheet_get_value (store->datasheet, row, var_get_dict_index (var), val);
 
   return TRUE;
 }
@@ -655,7 +669,7 @@ psppire_data_store_get_string (PsppireDataStore *store,
    Returns true if anything was updated, false otherwise.  */
 gboolean
 psppire_data_store_set_string (PsppireDataStore *store,
-			       const gchar *text,
+                               const gchar *text,
                                glong row, const struct variable *var,
                                gboolean use_value_label)
 {
@@ -669,7 +683,7 @@ psppire_data_store_set_string (PsppireDataStore *store,
   if (row == n_cases)
     psppire_data_store_insert_new_case (store, row);
 
-  case_index = var_get_case_index (var);
+  case_index = var_get_dict_index (var);
   if (use_value_label)
     {
       const struct val_labs *vls = var_get_value_labels (var);
@@ -712,8 +726,8 @@ psppire_data_store_get_reader (PsppireDataStore *ds)
   if (ds->dict)
     for (int i = 0 ; i < n_dict_signals; ++i)
       {
-	g_signal_handler_block (ds->dict,
-				ds->dict_handler_id[i]);
+        g_signal_handler_block (ds->dict,
+                                ds->dict_handler_id[i]);
       }
 
   reader = datasheet_make_reader (ds->datasheet);
@@ -728,7 +742,7 @@ psppire_data_store_get_reader (PsppireDataStore *ds)
  */
 struct ccase *
 psppire_data_store_get_case (const PsppireDataStore *ds,
-			     casenumber casenum)
+                             casenumber casenum)
 {
   g_return_val_if_fail (ds, FALSE);
   g_return_val_if_fail (ds->datasheet, FALSE);
@@ -739,13 +753,13 @@ psppire_data_store_get_case (const PsppireDataStore *ds,
 
 gboolean
 psppire_data_store_delete_cases (PsppireDataStore *ds, casenumber first,
-				 casenumber n_cases)
+                                 casenumber n_cases)
 {
   g_return_val_if_fail (ds, FALSE);
   g_return_val_if_fail (ds->datasheet, FALSE);
 
   g_return_val_if_fail (first + n_cases <=
-			psppire_data_store_get_case_count (ds), FALSE);
+                        psppire_data_store_get_case_count (ds), FALSE);
 
 
   datasheet_delete_rows (ds->datasheet, first, n_cases);
@@ -760,8 +774,8 @@ psppire_data_store_delete_cases (PsppireDataStore *ds, casenumber first,
 /* Insert case CC into the case file before POSN */
 static gboolean
 psppire_data_store_insert_case (PsppireDataStore *ds,
-				struct ccase *cc,
-				casenumber posn)
+                                struct ccase *cc,
+                                casenumber posn)
 {
   bool result ;
 
@@ -787,7 +801,7 @@ psppire_data_store_insert_case (PsppireDataStore *ds,
    Returns true if successful, false on I/O error. */
 gboolean
 psppire_data_store_set_value (PsppireDataStore *ds, casenumber casenum,
-			      const struct variable *var, const union value *v)
+                              const struct variable *var, const union value *v)
 {
   glong n_cases;
   bool ok;
@@ -802,7 +816,7 @@ psppire_data_store_set_value (PsppireDataStore *ds, casenumber casenum,
   if (casenum == n_cases)
     psppire_data_store_insert_new_case (ds, casenum);
 
-  ok = datasheet_put_value (ds->datasheet, casenum, var_get_case_index (var),
+  ok = datasheet_put_value (ds->datasheet, casenum, var_get_dict_index (var),
                             v);
   if (ok)
     {
@@ -819,7 +833,7 @@ psppire_data_store_set_value (PsppireDataStore *ds, casenumber casenum,
 /* Set the IDXth value of case C using D_IN */
 static gboolean
 psppire_data_store_data_in (PsppireDataStore *ds, casenumber casenum, gint idx,
-			    struct substring input, const struct fmt_spec *fmt)
+                            struct substring input, struct fmt_spec fmt)
 {
   union value value;
   int width;
@@ -840,7 +854,7 @@ psppire_data_store_data_in (PsppireDataStore *ds, casenumber casenum, gint idx,
                         FALSE);
   value_init (&value, width);
   ok = (datasheet_get_value (ds->datasheet, casenum, idx, &value)
-        && data_in_msg (input, UTF8, fmt->type, settings_get_fmt_settings (),
+        && data_in_msg (input, UTF8, fmt.type, settings_get_fmt_settings (),
                         &value, width, dict_get_encoding (dict->dict))
         && datasheet_put_value (ds->datasheet, casenum, idx, &value));
   value_destroy (&value, width);
@@ -895,7 +909,7 @@ psppire_data_store_filtered (PsppireDataStore *ds,
   g_return_val_if_fail (var_is_numeric (filter), FALSE);
   value_init (&val, 0);
   if (! datasheet_get_value (ds->datasheet, row,
-                              var_get_case_index (filter),
+                              var_get_dict_index (filter),
                               &val))
     return FALSE;
 
