@@ -70,7 +70,7 @@ psppire_dialog_action_histogram_activate (PsppireDialogAction *a, GVariant *para
   pda->source = get_widget_assert (xml, "dict-view");
 
   g_object_set (pda->source,
-		"predicate", var_is_numeric, NULL);
+                "predicate", var_is_numeric, NULL);
 
   act->variable = get_widget_assert (xml, "entry1");
   act->curve = get_widget_assert (xml, "curve");
@@ -78,7 +78,7 @@ psppire_dialog_action_histogram_activate (PsppireDialogAction *a, GVariant *para
   psppire_dialog_action_set_refresh (pda, refresh);
 
   psppire_dialog_action_set_valid_predicate (pda,
-					dialog_state_valid);
+                                        dialog_state_valid);
 
   return xml;
 }
@@ -89,7 +89,6 @@ static char *
 generate_syntax (const PsppireDialogAction *a)
 {
   PsppireDialogActionHistogram *rd = PSPPIRE_DIALOG_ACTION_HISTOGRAM (a);
-  gchar *text;
   const gchar *var_name = gtk_entry_get_text (GTK_ENTRY (rd->variable));
   GString *string = g_string_new ("GRAPH /HISTOGRAM ");
 
@@ -103,11 +102,7 @@ generate_syntax (const PsppireDialogAction *a)
 
   g_string_append (string, ".\n");
 
-  text = string->str;
-
-  g_string_free (string, FALSE);
-
-  return text;
+  return g_string_free_and_steal (string);
 }
 
 static void
