@@ -54,7 +54,6 @@ static char *
 generate_syntax (const PsppireDialogAction *act)
 {
   PsppireDialogActionRuns *rd = PSPPIRE_DIALOG_ACTION_RUNS (act);
-  gchar *str;
 
   GString *string = g_string_new ("NPAR TEST");
 
@@ -75,11 +74,7 @@ generate_syntax (const PsppireDialogAction *act)
 
   g_string_append (string, ".\n");
 
-  str = string->str;
-
-  g_string_free (string, FALSE);
-
-  return str;
+  return g_string_free_and_steal (string);
 }
 
 
@@ -97,7 +92,7 @@ dialog_state_valid (gpointer data)
   for (i = 0; i < 4; ++i)
     {
       if (TRUE == gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (fd->cb[i])))
-	break;
+        break;
     }
   if (i >= 4)
     return FALSE;
@@ -106,7 +101,7 @@ dialog_state_valid (gpointer data)
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (fd->cb[CB_CUSTOM])))
     {
       if (0 == strcmp ("", gtk_entry_get_text (GTK_ENTRY (fd->entry))))
-	return FALSE;
+        return FALSE;
     }
 
   return TRUE;
