@@ -33,30 +33,25 @@ static char *
 generate_syntax (const PsppireDialogAction *act)
 {
   PsppireDialogActionSort *scd = PSPPIRE_DIALOG_ACTION_SORT (act);
-  gchar *text;
   GString *string = g_string_new ("SORT CASES BY ");
 
   PsppireVarView *var_view = PSPPIRE_VAR_VIEW (scd->variables);
   gint n_vars = psppire_var_view_append_names (var_view, 0, string);
 
-  if ( n_vars == 0 )
+  if (n_vars == 0)
     {
       g_string_assign (string, "");
     }
   else
     {
       const char up_down =
-	(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (scd->ascending))
+        (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (scd->ascending))
          ? 'A' : 'D');
       g_string_append_printf (string, "(%c)", up_down);
       g_string_append (string, ".");
     }
 
-  text = string->str;
-
-  g_string_free (string, FALSE);
-
-  return text;
+  return g_string_free_and_steal (string);
 }
 
 static void
@@ -82,49 +77,41 @@ dialog_state_valid (gpointer act)
 
   gint n_rows = gtk_tree_model_iter_n_children  (model, NULL);
 
-  if ( n_rows == 0 )
+  if (n_rows == 0)
     return FALSE;
 
   return TRUE;
 }
 
 
-static void
-psppire_dialog_action_sort_activate (PsppireDialogAction *a)
+static GtkBuilder *
+psppire_dialog_action_sort_activate (PsppireDialogAction *a, GVariant *param)
 {
   PsppireDialogAction *pda = PSPPIRE_DIALOG_ACTION (a);
   PsppireDialogActionSort *act = PSPPIRE_DIALOG_ACTION_SORT (a);
 
-  GHashTable *thing = psppire_dialog_action_get_hash_table (pda);
-  GtkBuilder *xml = g_hash_table_lookup (thing, a);
-  if (!xml)
-    {
-      xml = builder_new ("sort.ui");
-      g_hash_table_insert (thing, a, xml);
-    }
+  GtkBuilder *xml = builder_new ("sort.ui");
 
   pda->dialog = get_widget_assert (xml, "sort-cases-dialog");
   pda->source = get_widget_assert (xml, "sort-cases-treeview1");
-  
+
   act->variables =  get_widget_assert (xml, "sort-cases-treeview2");
   act->ascending = get_widget_assert (xml, "sort-cases-radiobutton0");
 
   psppire_dialog_action_set_refresh (pda, reset);
 
   psppire_dialog_action_set_valid_predicate (pda,
-				      dialog_state_valid);
-
-  if (PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_sort_parent_class)->activate)
-    PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_sort_parent_class)->activate (pda);
+                                      dialog_state_valid);
+  return xml;
 }
 
 static void
 psppire_dialog_action_sort_class_init (PsppireDialogActionSortClass *class)
 {
  PsppireDialogActionClass *pdac = PSPPIRE_DIALOG_ACTION_CLASS (class);
-  psppire_dialog_action_set_activation (class, psppire_dialog_action_sort_activate);
+  PSPPIRE_DIALOG_ACTION_CLASS (class)->initial_activate = psppire_dialog_action_sort_activate;
 
-  pdac->generate_syntax = generate_syntax;
+ pdac->generate_syntax = generate_syntax;
 }
 
 
