@@ -67,9 +67,9 @@ enum
 
 static void
 psppire_dialog_get_property (GObject         *object,
-			     guint            prop_id,
-			     GValue          *value,
-			     GParamSpec      *pspec)
+                             guint            prop_id,
+                             GValue          *value,
+                             GParamSpec      *pspec)
 {
   PsppireDialog *dialog = PSPPIRE_DIALOG (object);
 
@@ -89,9 +89,9 @@ psppire_dialog_get_property (GObject         *object,
 
 static void
 psppire_dialog_set_property (GObject         *object,
-			     guint            prop_id,
-			     const GValue    *value,
-			     GParamSpec      *pspec)
+                             guint            prop_id,
+                             const GValue    *value,
+                             GParamSpec      *pspec)
 
 {
   PsppireDialog *dialog = PSPPIRE_DIALOG (object);
@@ -122,17 +122,17 @@ psppire_dialog_class_init (PsppireDialogClass *class)
 
   help_page_spec =
     g_param_spec_string ("help-page",
-			 "Help Page",
-			 "The section of the manual to load when the Help button is clicked",
-			 NULL,
-			 G_PARAM_READWRITE);
+                         "Help Page",
+                         "The section of the manual to load when the Help button is clicked",
+                         NULL,
+                         G_PARAM_READWRITE);
 
   sliding_spec =
     g_param_spec_boolean ("slidable",
-			  "Slidable",
-			  "Can the container be sized by the user",
-			  FALSE,
-			  G_PARAM_CONSTRUCT_ONLY |G_PARAM_READWRITE);
+                          "Slidable",
+                          "Can the container be sized by the user",
+                          FALSE,
+                          G_PARAM_CONSTRUCT_ONLY |G_PARAM_READWRITE);
 
   object_class->set_property = psppire_dialog_set_property;
   object_class->get_property = psppire_dialog_get_property;
@@ -148,49 +148,49 @@ psppire_dialog_class_init (PsppireDialogClass *class)
 
   signals [DIALOG_REFRESH] =
     g_signal_new ("refresh",
-		  G_TYPE_FROM_CLASS (class),
-		  G_SIGNAL_RUN_FIRST,
-		  0,
-		  NULL, NULL,
-		  g_cclosure_marshal_VOID__VOID,
-		  G_TYPE_NONE,
-		  0);
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_FIRST,
+                  0,
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__VOID,
+                  G_TYPE_NONE,
+                  0);
 
 
   signals [RESPONSE] =
     g_signal_new ("response",
-		  G_TYPE_FROM_CLASS (class),
-		  G_SIGNAL_RUN_FIRST,
-		  0,
-		  NULL, NULL,
-		  g_cclosure_marshal_VOID__INT,
-		  G_TYPE_NONE,
-		  1,
-		  G_TYPE_INT);
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_FIRST,
+                  0,
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__INT,
+                  G_TYPE_NONE,
+                  1,
+                  G_TYPE_INT);
 
 
   signals [VALIDITY_CHANGED] =
     g_signal_new ("validity-changed",
-		  G_TYPE_FROM_CLASS (class),
-		  G_SIGNAL_RUN_FIRST,
-		  0,
-		  NULL, NULL,
-		  g_cclosure_marshal_VOID__BOOLEAN,
-		  G_TYPE_NONE,
-		  1,
-		  G_TYPE_BOOLEAN);
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_FIRST,
+                  0,
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__BOOLEAN,
+                  G_TYPE_NONE,
+                  1,
+                  G_TYPE_BOOLEAN);
 
 
   signals [DIALOG_HELP] =
     g_signal_new ("help",
-		  G_TYPE_FROM_CLASS (class),
-		  G_SIGNAL_RUN_FIRST,
-		  0,
-		  NULL, NULL,
-		  g_cclosure_marshal_VOID__STRING,
-		  G_TYPE_NONE,
-		  1,
-		  G_TYPE_STRING);
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_FIRST,
+                  0,
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__STRING,
+                  G_TYPE_NONE,
+                  1,
+                  G_TYPE_STRING);
 
   parent_class = g_type_class_peek_parent (class);
 }
@@ -228,14 +228,14 @@ psppire_dialog_init (PsppireDialog *dialog)
   dialog->help_page = NULL;
 
   gtk_window_set_type_hint (GTK_WINDOW (dialog),
-	GDK_WINDOW_TYPE_HINT_DIALOG);
+        GDK_WINDOW_TYPE_HINT_DIALOG);
 
   g_signal_connect (dialog, "delete-event",
-		    G_CALLBACK (delete_event_callback),
-		    dialog);
+                    G_CALLBACK (delete_event_callback),
+                    dialog);
 
   gtk_window_set_type_hint (GTK_WINDOW (dialog),
-	GDK_WINDOW_TYPE_HINT_DIALOG);
+        GDK_WINDOW_TYPE_HINT_DIALOG);
 
   g_object_set (dialog, "icon-name", "org.gnu.pspp", NULL);
 }
@@ -246,7 +246,7 @@ psppire_dialog_new (void)
   PsppireDialog *dialog ;
 
   dialog = g_object_new (psppire_dialog_get_type (),
-			 NULL);
+                         NULL);
 
   return GTK_WIDGET (dialog) ;
 }
@@ -277,31 +277,37 @@ connect_notify_signal (GtkWidget *w, gpointer data)
   if (GTK_IS_CONTAINER (w))
     {
       gtk_container_foreach (GTK_CONTAINER (w),
-			     connect_notify_signal,
-			     dialog);
+                             connect_notify_signal,
+                             dialog);
     }
 
-
   /* It's unfortunate that GTK+ doesn't have a generic
      "user-modified-state-changed" signal.  Instead, we have to try and
      predict what widgets and signals are likely to exist in our dialogs. */
 
+  if (GTK_IS_DRAWING_AREA (w))
+    {
+      g_signal_connect_swapped (w, "draw",
+                                G_CALLBACK (psppire_dialog_notify_change),
+                                dialog);
+    }
+
   if (GTK_IS_TOGGLE_BUTTON (w))
     {
       g_signal_connect_swapped (w, "toggled",
-				G_CALLBACK (psppire_dialog_notify_change),
-				dialog);
+                                G_CALLBACK (psppire_dialog_notify_change),
+                                dialog);
     }
 
   if (PSPPIRE_IS_SELECTOR (w))
     {
       g_signal_connect_swapped (w, "selected",
-				G_CALLBACK (psppire_dialog_notify_change),
-				dialog);
+                                G_CALLBACK (psppire_dialog_notify_change),
+                                dialog);
 
       g_signal_connect_swapped (w, "de-selected",
-				G_CALLBACK (psppire_dialog_notify_change),
-				dialog);
+                                G_CALLBACK (psppire_dialog_notify_change),
+                                dialog);
 
       psppire_selector_update_subjects (PSPPIRE_SELECTOR (w));
     }
@@ -309,15 +315,15 @@ connect_notify_signal (GtkWidget *w, gpointer data)
   if (GTK_IS_EDITABLE (w))
     {
       g_signal_connect_swapped (w, "changed",
-				G_CALLBACK (psppire_dialog_notify_change),
-				dialog);
+                                G_CALLBACK (psppire_dialog_notify_change),
+                                dialog);
     }
 
   if (GTK_IS_CELL_EDITABLE (w))
     {
       g_signal_connect_swapped (w, "editing-done",
-				G_CALLBACK (psppire_dialog_notify_change),
-				dialog);
+                                G_CALLBACK (psppire_dialog_notify_change),
+                                dialog);
     }
 
   if (GTK_IS_TEXT_VIEW (w))
@@ -325,8 +331,8 @@ connect_notify_signal (GtkWidget *w, gpointer data)
       GtkTextBuffer *buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (w));
 
       g_signal_connect_swapped (buffer, "changed",
-				G_CALLBACK (psppire_dialog_notify_change),
-				dialog);
+                                G_CALLBACK (psppire_dialog_notify_change),
+                                dialog);
     }
 
   if (GTK_IS_TREE_VIEW (w))
@@ -334,43 +340,43 @@ connect_notify_signal (GtkWidget *w, gpointer data)
       gint i = 0;
       GtkTreeView *tv = GTK_TREE_VIEW (w);
       GtkTreeSelection *selection =
-	gtk_tree_view_get_selection (tv);
+        gtk_tree_view_get_selection (tv);
       GtkTreeViewColumn *col;
       GtkTreeModel *model = gtk_tree_view_get_model (tv);
 
       if (model)
-	{
-	  g_signal_connect_swapped (model, "row-changed",
-				    G_CALLBACK (psppire_dialog_notify_change),
-				    dialog);
+        {
+          g_signal_connect_swapped (model, "row-changed",
+                                    G_CALLBACK (psppire_dialog_notify_change),
+                                    dialog);
 
-	  g_signal_connect_swapped (model, "row-deleted",
-				    G_CALLBACK (psppire_dialog_notify_change),
-				    dialog);
+          g_signal_connect_swapped (model, "row-deleted",
+                                    G_CALLBACK (psppire_dialog_notify_change),
+                                    dialog);
 
-	  g_signal_connect_swapped (model, "row-inserted",
-				    G_CALLBACK (psppire_dialog_notify_change),
-				    dialog);
+          g_signal_connect_swapped (model, "row-inserted",
+                                    G_CALLBACK (psppire_dialog_notify_change),
+                                    dialog);
 
-	}
+        }
 
       g_signal_connect_swapped (selection, "changed",
-				G_CALLBACK (psppire_dialog_notify_change),
-				dialog);
+                                G_CALLBACK (psppire_dialog_notify_change),
+                                dialog);
 
       while ((col = gtk_tree_view_get_column (tv, i++)))
-	{
-	  GList *renderers = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (col));
-	  GList *start = renderers;
-	  while (renderers)
-	    {
-	      if (GTK_IS_CELL_RENDERER_TOGGLE (renderers->data))
-		g_signal_connect_swapped (renderers->data, "toggled",
-					  G_CALLBACK (psppire_dialog_notify_change), dialog);
-	      renderers = renderers->next;
-	    }
-	  g_list_free (start);
-	}
+        {
+          GList *renderers = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (col));
+          GList *start = renderers;
+          while (renderers)
+            {
+              if (GTK_IS_CELL_RENDERER_TOGGLE (renderers->data))
+                g_signal_connect_swapped (renderers->data, "toggled",
+                                          G_CALLBACK (psppire_dialog_notify_change), dialog);
+              renderers = renderers->next;
+            }
+          g_list_free (start);
+        }
     }
 }
 
@@ -386,8 +392,8 @@ psppire_dialog_run (PsppireDialog *dialog)
 
   if (dialog->contents_are_valid != NULL)
     gtk_container_foreach (GTK_CONTAINER (gtk_bin_get_child(GTK_BIN(dialog))),
-			   connect_notify_signal,
-			   dialog);
+                           connect_notify_signal,
+                           dialog);
 
   dialog->loop = g_main_loop_new (NULL, FALSE);
 
@@ -431,8 +437,8 @@ psppire_dialog_help (PsppireDialog *dialog)
    disabled. */
 void
 psppire_dialog_set_valid_predicate (PsppireDialog *dialog,
-				    ContentsAreValid contents_are_valid,
-				    gpointer data)
+                                    ContentsAreValid contents_are_valid,
+                                    gpointer data)
 {
   dialog->contents_are_valid = contents_are_valid;
   dialog->validity_data = data;
