@@ -149,7 +149,7 @@ syntax_gen_number (struct string *output,
 {
   assert (format == NULL || fmt_is_numeric (format->type));
   if (format != NULL
-      && (format->type
+      && (fmt_get_category (format->type)
           & (FMT_CAT_DATE | FMT_CAT_TIME | FMT_CAT_DATE_COMPONENT)))
     {
       union value v_in, v_out;
@@ -157,7 +157,7 @@ syntax_gen_number (struct string *output,
       bool ok;
 
       v_in.f = number;
-      s = data_out (&v_in, "FIXME", format, settings_get_fmt_settings ());
+      s = data_out (&v_in, "FIXME", *format, settings_get_fmt_settings ());
 
       /* FIXME: UTF8 encoded strings will fail here */
       error = data_in (ss_cstr (s), C_ENCODING, format->type,
@@ -168,7 +168,7 @@ syntax_gen_number (struct string *output,
       if (ok && v_out.f == number)
         {
           syntax_gen_string (output, ss_cstr (s));
-	  free (s);
+          free (s);
           return;
         }
       free (s);
@@ -194,7 +194,7 @@ void
 syntax_gen_value (struct string *output, const union value *value, int width,
                   const struct fmt_spec *format)
 {
-  assert (format == NULL || fmt_var_width (format) == width);
+  assert (format == NULL || fmt_var_width (*format) == width);
   if (width == 0)
     syntax_gen_number (output, value->f, format);
   else
@@ -283,12 +283,12 @@ syntax_gen_pspp_valist (struct string *output, const char *format,
           break;
 
         case 'f':
-	case 'g':
+        case 'g':
           {
-	    char conv[32];
+            char conv[32];
             double d = va_arg (args, double);
             int x = 0;
-	    conv[x++] = '%';
+            conv[x++] = '%';
             conv[x] = '\0';
             if (precision != -1)
               {
@@ -296,8 +296,8 @@ syntax_gen_pspp_valist (struct string *output, const char *format,
                 strcat (conv, qualifier);
                 x += strlen (qualifier) + 1;
               }
-	    conv[x++] = directive;
-	    conv[x++] = '\0';
+            conv[x++] = directive;
+            conv[x++] = '\0';
 
             ds_put_c_format (output, conv, d);
             break;
