@@ -23,6 +23,7 @@
 #include <unistd.h>
 
 #include "data/any-reader.h"
+#include "data/case-map.h"
 #include "data/casereader.h"
 #include "data/casewriter.h"
 #include "data/csv-file-writer.h"
@@ -80,7 +81,7 @@ parse_variables_option (const char *arg, struct dictionary *dict,
   bool ok = parse_variables (lexer, dict, vars, n_vars, 0);
   if (ok && (lex_token (lexer) != T_STOP && lex_token (lexer) != T_ENDCMD))
     {
-      lex_error (lexer, _("expecting variable name"));
+      lex_error (lexer, _("Syntax error expecting variable name."));
       ok = false;
     }
 
@@ -286,7 +287,7 @@ main (int argc, char *argv[])
                          ds_cstr (&alphabet), length, password_list))
         goto exit;
       else
-	goto error;
+        goto error;
     }
 
 
@@ -294,6 +295,7 @@ main (int argc, char *argv[])
   if (reader == NULL)
     goto error;
 
+  struct case_map_stage *stage = case_map_stage_create (dict);
   if (keep)
     {
       struct variable **keep_vars;
@@ -316,6 +318,9 @@ main (int argc, char *argv[])
       free (drop_vars);
     }
 
+  reader = case_map_create_input_translator (
+    case_map_stage_to_case_map (stage), reader);
+
   if (!strcmp (output_format, "csv") || !strcmp (output_format, "txt"))
     {
       if (!csv_opts.delimiter)
@@ -385,8 +390,8 @@ error:
 
 static bool
 decrypt_file (struct encrypted_file *enc,
-	      const struct file_handle *ifh,
-	      const struct file_handle *ofh,
+              const struct file_handle *ifh,
+              const struct file_handle *ofh,
               const char *password,
               const char *alphabet,
               int max_length,
