@@ -76,6 +76,7 @@ static void read_machine_float_info (struct sfm_reader *,
                                      size_t size, size_t count);
 static void read_extra_product_info (struct sfm_reader *,
                                      size_t size, size_t count);
+static void read_variable_sets (struct sfm_reader *, size_t size, size_t count);
 static void read_mrsets (struct sfm_reader *, size_t size, size_t count);
 static void read_display_parameters (struct sfm_reader *,
                                      size_t size, size_t count);
@@ -89,7 +90,7 @@ static void read_variable_attributes (struct sfm_reader *r,
                                       size_t size, size_t count);
 static void read_ncases64 (struct sfm_reader *, size_t size, size_t count);
 static void read_character_encoding (struct sfm_reader *r,
-				       size_t size, size_t count);
+                                       size_t size, size_t count);
 static void read_long_string_value_labels (struct sfm_reader *r,
                                            size_t size, size_t count);
 static void read_long_string_missing_values (struct sfm_reader *r,
@@ -607,6 +608,10 @@ read_extension_record (struct sfm_reader *r)
       read_machine_float_info (r, size, count);
       return;
 
+    case 5:
+      read_variable_sets (r, size, count);
+      return;
+
     case 6:
       /* DATE variable information.  We don't use it yet, but we
          should. */
@@ -730,6 +735,38 @@ read_machine_float_info (struct sfm_reader *r, size_t size, size_t count)
               DBL_DIG + 1, lowest, lowest, "LOWEST");
 }
 
+/* Read record type 7, subtype 5. */
+static void
+read_variable_sets (struct sfm_reader *r, size_t size, size_t count)
+{
+  printf ("%08llx: variable sets\n", (long long int) ftello (r->file));
+  struct text_record *text = open_text_record (r, size, count);
+  for (;;)
+    {
+      while (text_match (text, '\n'))
+        continue;
+
+      const char *set = text_tokenize (text, '=');
+      if (!set)
+        break;
+
+      /* Always present even for an empty set. */
+      text_match (text, ' ');
+
+      char *variables = text_tokenize (text, '\n');
+      if (!variables)
+        printf ("\tset \"%s\" is empty\n", set);
+      else
+        {
+          size_t length = strlen (variables);
+          if (variables[length - 1] == '\r')
+            variables[length - 1] = '\0';
+          printf ("\tset \"%s\" contains \"%s\"\n", set, variables);
+        }
+    }
+  close_text_record (text);
+}
+
 static void
 read_extra_product_info (struct sfm_reader *r,
                          size_t size, size_t count)
@@ -1056,31 +1093,37 @@ read_long_string_value_labels (struct sfm_reader *r, size_t size, size_t count)
 
       /* Read values. */
       for (i = 0; i < n_values; i++)
-	{
-          char *value;
+        {
+          char *value = NULL;
           int value_length;
 
-          char *label;
-	  int label_length;
+          char *label = NULL;
+          int label_length;
 
           posn = ftello (r->file);
 
           /* Read value. */
           value_length = read_int (r);
-          value = xmalloc (value_length + 1);
-          read_string (r, value, value_length + 1);
+          if (value_length > 0)
+            {
+              value = xmalloc (value_length + 1);
+              read_string (r, value, value_length + 1);
+            }
 
           /* Read label. */
           label_length = read_int (r);
-          label = xmalloc (label_length + 1);
-          read_string (r, label, label_length + 1);
+          if (label_length > 0)
+            {
+              label = xmalloc (label_length + 1);
+              read_string (r, label, label_length + 1);
+            }
 
           printf ("\t\t%08llx: \"%s\" (%d bytes) => \"%s\" (%d bytes)\n",
                   posn, value, value_length, label, label_length);
 
           free (value);
           free (label);
-	}
+        }
     }
 }
 
@@ -1094,42 +1137,39 @@ read_long_string_missing_values (struct sfm_reader *r,
   while (ftello (r->file) - start < size * count)
     {
       long long posn = ftello (r->file);
-      char var_name[ID_MAX_LEN + 1];
-      uint8_t n_missing_values;
-      int var_name_len;
-      int i;
 
       /* Read variable name. */
-      var_name_len = read_int (r);
+      int var_name_len = read_int (r);
       if (var_name_len > ID_MAX_LEN)
         sys_error (r, "Variable name length in long string value label "
                    "record (%d) exceeds %d-byte limit.",
                    var_name_len, ID_MAX_LEN);
+      char var_name[ID_MAX_LEN + 1];
       read_string (r, var_name, var_name_len + 1);
 
       /* Read number of values. */
+      uint8_t n_missing_values;
       read_bytes (r, &n_missing_values, 1);
 
-      printf ("\t%08llx: %s, %d missing values:",
-              posn, var_name, n_missing_values);
+      /* Read value length. */
+      int value_length = read_int (r);
+
+      printf ("\t%08llx: %s, %d missing values, each %d bytes:",
+              posn, var_name, n_missing_values, value_length);
 
       /* Read values. */
-      for (i = 0; i < n_missing_values; i++)
-	{
-          char *value;
-          int value_length;
-
+      for (int i = 0; i < n_missing_values; i++)
+        {
           posn = ftello (r->file);
 
           /* Read value. */
-          value_length = read_int (r);
-          value = xmalloc (value_length + 1);
+          char *value = xmalloc (value_length + 1);
           read_string (r, value, value_length + 1);
 
           printf (" \"%s\"", value);
 
           free (value);
-	}
+        }
       printf ("\n");
     }
 }
@@ -1251,7 +1291,7 @@ read_simple_compressed_data (struct sfm_reader *r, int max_cases)
             }
           opcode = opcodes[opcode_idx];
           printf ("%08llx: variable %d: opcode %d: ",
-                  opcode_ofs + opcode_idx, i, opcode);
+                  opcode_ofs + opcode_idx, i + 1, opcode);
 
           switch (opcode)
             {
@@ -1401,7 +1441,7 @@ open_text_record (struct sfm_reader *r, size_t size, size_t count)
 {
   struct text_record *text = xmalloc (sizeof *text);
 
-  if (size_overflow_p (xsum (1, xtimes (size, count))))
+  if (size > 0 && size_overflow_p (xsum (1, xtimes (count, size))))
     sys_error (r, "Extension record too large.");
 
   size_t n_bytes = size * count;
@@ -1451,7 +1491,7 @@ text_match (struct text_record *text, int c)
     return false;
 }
 
-/* Reads a integer value expressed in decimal, then a space, then a string that
+/* Reads an integer value expressed in decimal, then a space, then a string that
    consists of exactly as many bytes as specified by the integer, then a space,
    from TEXT.  Returns the string, null-terminated, as a subset of TEXT's
    buffer (so the caller should not free the string). */
